using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using CADImport;
using CADImport.FaceModule;

namespace CADImportNetDemos.AddEntityDemo
{
    public partial class AddArcForm : Form
    {
        private CADImage cadImage;
        private CADArc arc;
        private ColorDialog setColorDlg;

        #region Help
        /// <summary>
        /// Gets or sets <see cref="CADImport.CADImage">CADImage</see> object where new entities are added
        /// </summary>
        #endregion
        public CADImage Image
        {
            get
            {
                return this.cadImage;
            }
            set
            {
                this.cadImage = value;
            }
        }
        
        public AddArcForm()
        {
            InitializeComponent();
            setColorDlg = new ColorDialog();
            cbLineWeight.SelectedItem = ApplicationConstants.onestr;
        }

        private void bColor_Click(object sender, EventArgs e)
        {
            if (setColorDlg.ShowDialog() == DialogResult.OK)
                this.tbColor.BackColor = setColorDlg.Color;	
        }

        private void bOk_Click(object sender, EventArgs e)
        {
            arc = new CADArc();
            if (setColorDlg.Color == Color.Black)
                arc.Color = CADConst.clNone;
            else
                arc.Color = setColorDlg.Color;
            try
            {
                arc.Radius = Convert.ToDouble(this.tbRadius.Text);
                arc.Point = new DPoint(Convert.ToDouble(this.tbX.Text), Convert.ToDouble(this.tbY.Text), Convert.ToDouble(this.tbZ.Text));
                arc.LineWeight = Convert.ToSingle(this.cbLineWeight.Text, ApplicationConstants.numInfo);
                arc.StartAngle = Convert.ToDouble(this.tbStartAngle.Text);
                arc.EndAngle = Convert.ToDouble(this.tbEndAngle.Text);
                cadImage.Converter.GetSection(ConvSection.Entities).AddEntity(arc);
                cadImage.Converter.OnCreate(arc);
                cadImage.Converter.Loads(arc);
                this.OnResizeImage();
            }
            catch (FormatException exception)
            {
                MessageBox.Show(exception.Message, ApplicationConstants.appconst, MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
            }
            this.DialogResult = DialogResult.OK;
            this.Close();
        }
    }
}