Imports System.Windows.Forms
Imports System.Drawing
Imports System.Drawing.Imaging
Imports System.ComponentModel
Imports System.IO
Imports CADImport
Imports CADImport.CADImportForms
Imports CADImport.FaceModule
Imports CADImport.Printing
Imports CADImport.RasterImage
Imports CADImport.Export.DirectCADtoDXF
''' <summary>
''' Represents the main application form of the viewer in which CAD files can be opened and viewed.
''' </summary>
Public Class MainForm
    Inherits Form    
    Private aboutFrm As AboutForm
    Private cADFilesMenuItem As MenuItem
    Private cadImageFld As CADImage
    Private WithEvents cadPictBox As CADPictureBox
    Private WithEvents cbLayouts As ComboBox
    Private clipRectangle As ClipRect
    Private components As IContainer
    Private curLngIndex As Integer
    Private cX As Integer
    Private cY As Integer
    Private detRMouseDown As Boolean
    Private dimVisible As Boolean
    Private dlgOpenFile As OpenFileDialog
    Private dlgOpenSerializeFile As OpenFileDialog
    Private dlgSaveDXF As SaveFileDialog
    Private dlgSaveImg As SaveFileDialog
    Private dlgSaveSerializeFile As SaveFileDialog
    Private dlgSetColor As ColorDialog
    Private drawMode As Boolean
    Private editMenuItem As MenuItem
    Private Shared ReadOnly fileSettingsName As String = (Application.StartupPath & "\Settings.txt")
    Private floatLicFrm As FloatLicForm
    Private helpMenuItem As MenuItem
    Private imgLstToolBtn As ImageList
    Private lbLayouts As Label
    Private lForm As LayerForm
    Private listItemSelectDel As ListItemSelectEventHandler
    Private lngFile As String
    Private mainMenu As MainMenu
    Private menuOrbitView As ContextMenu
    Private WithEvents mi3DViews As MenuItem
    Private WithEvents miAbout As MenuItem
    Private WithEvents miArcsSplit As MenuItem
    Private WithEvents miBackOrbitView As MenuItem
    Private WithEvents miBackView As MenuItem
    Private WithEvents miBlackBackground As MenuItem
    Private WithEvents miBottomOrbitView As MenuItem
    Private WithEvents miBottomView As MenuItem
    Private WithEvents miChangeBackgroundColor As MenuItem
    Private WithEvents miClosePicture As MenuItem
    Private WithEvents miCopyAsBMP As MenuItem
    Private WithEvents miCustomPrint As MenuItem
    Private WithEvents miDimShow As MenuItem
    Private WithEvents miDrawBlackColor As MenuItem
    Private WithEvents miDrawNormalColor As MenuItem
    Private WithEvents miEnable3DOrbit As MenuItem
    Private WithEvents miExit As MenuItem
    Private WithEvents miFile As MenuItem
    Private WithEvents miFitToWindow As MenuItem
    Private WithEvents miFloatLic As MenuItem
    Private WithEvents miFrontOrbitView As MenuItem
    Private WithEvents miFrontView As MenuItem
    Private WithEvents miInitialOrbitView As MenuItem
    Private WithEvents miInitialView As MenuItem
    Private WithEvents miLanguages As MenuItem
    Private WithEvents miLayersShow As MenuItem
    Private WithEvents miLeftOrbitView As MenuItem
    Private WithEvents miLeftView As MenuItem
    Private WithEvents miNEIsometricView As MenuItem
    Private WithEvents miNEOrbitView As MenuItem
    Private WithEvents miNWIsometricView As MenuItem
    Private WithEvents miNWOrbitView As MenuItem
    Private WithEvents miOpenFile As MenuItem
    Private WithEvents miOpenFromWeb As MenuItem
    Private WithEvents miPrint As MenuItem
    Private WithEvents miPrintPreview As MenuItem
    Private WithEvents miRegistration As MenuItem
    Private WithEvents miRightOrbitView As MenuItem
    Private WithEvents miRightView As MenuItem
    Private WithEvents miSaveAsDXF As MenuItem
    Private WithEvents miSaveFile As MenuItem
    Private WithEvents miScale As MenuItem
    Private WithEvents miSEIsometricView As MenuItem
    Private WithEvents miSEOrbitView As MenuItem
    Private WithEvents miSeparator1 As MenuItem
    Private WithEvents miSeparator2 As MenuItem
    Private WithEvents miSeparator3 As MenuItem
    Private WithEvents miSeparator4 As MenuItem
    Private WithEvents miSeparator5 As MenuItem
    Private WithEvents miShowEntityTree As MenuItem
    Private WithEvents miShowLineWeight As MenuItem
    Private WithEvents miShowOptionsForm As MenuItem
    Private WithEvents miShowShxForm As MenuItem
    Private WithEvents miSWIsometricView As MenuItem
    Private WithEvents miSWOrbitView As MenuItem
    Private WithEvents miTextsShow As MenuItem
    Private WithEvents miTopOrbitView As MenuItem
    Private WithEvents miTopView As MenuItem
    Private WithEvents miWhiteBackground As MenuItem
    Private WithEvents miZoom10 As MenuItem
    Private WithEvents miZoom100 As MenuItem
    Private WithEvents miZoom200 As MenuItem
    Private WithEvents miZoom25 As MenuItem
    Private WithEvents miZoom400 As MenuItem
    Private WithEvents miZoom50 As MenuItem
    Private WithEvents miZoom800 As MenuItem
    Private WithEvents miZoomIn As MenuItem
    Private WithEvents miZoomOut As MenuItem
    Private mlng As MultipleLanguage
    Private mView As MenuItem
    Private old_Pos As PointF
    Private Shared openFileName As String = String.Empty
    Private openFromWebForm As OpenFileFromWebForm
    Private optForm As OptionsForm
    Private orb3D As Orbit3D
    Private pnlLayouts As Panel
    Private pos As PointF
    Private prev_sc As Single
    Private printPrevDlg As PrintPreviewDialog
    Private WithEvents propGrid As PropertyGrid
    Private prtForm As PrintingForm
    Private rasterSizeForm As SetRasterSizeForm
    Private regFrm As RegForm
    Private sbCoord As StatusBarPanel
    Private sbOpen As StatusBarPanel
    Private sbScale As StatusBarPanel
    Private sc As Single
    Private settingsLst As SortedList
    Private showLineWeight As Boolean
    Private shxFrm As SHXForm
    Private spPropGrid As Splitter
    Private WithEvents spTree As Splitter
    Private stBar As StatusBar
    Private svSet As SaveSettings
    Private textVisible As Boolean
    Private tlb3d As ToolBarButton
    Private tlbArcPoly As ToolBarButton
    Private tlbAxes As ToolBarButton
    Private tlbBlack As ToolBarButton
    Private tlbBlackMode As ToolBarButton
    Private tlbColor As ToolBarButton
    Private tlbColorMode As ToolBarButton
    Private tlbDefSize As ToolBarButton
    Private tlbDimShow As ToolBarButton
    Private tlbLay As ToolBarButton
    Private tlbOpen As ToolBarButton
    Private tlbOpenFromClipboard As ToolBarButton
    Private tlbPrint As ToolBarButton
    Private tlbRect As ToolBarButton
    Private tlbRotateAngle As ToolBarButton
    Private tlbRotateLeft As ToolBarButton
    Private tlbRotateRight As ToolBarButton
    Private tlbSave As ToolBarButton
    Private tlbSaveImageClip As ToolBarButton
    Private tlbSelObject As ToolBarButton
    Private tlbSHX As ToolBarButton
    Private tlbTextShow As ToolBarButton
    Private WithEvents tlbTool As ToolBar
    Private tlbUseDoubleBuffering As ToolBarButton
    Private tlbWhite As ToolBarButton
    Private tlbZoomIn As ToolBarButton
    Private tlbZoomOut As ToolBarButton
    Private WithEvents trvEntity As TreeView
    Private trvPanel As Panel
    Private useDoubleBuffering As Boolean
    Private useSelectEntity As Boolean
    Private useSHXFonts As Boolean
    Private useWinEllipse As Boolean
    Private visibleArea As SizeF

    ' Methods
    ''' <summary>
    ''' Initializes a new instance of the <see cref="T:CADImportNetDemos.CADViewerDemo.MainForm">MainForm</see> class.
    ''' </summary>
    Public Sub New()
        Me.InitParams()
        Me.InitializeComponent()
        Me.InitExtParam()
    End Sub

    <System.STAThread()> _
   Public Shared Sub Main()
        Application.EnableVisualStyles()
        Application.DoEvents()
        Application.Run(New MainForm)
    End Sub


    Private Sub AddRecordToLayerList(ByVal name As String, ByVal color As Color, ByVal visible As Boolean, ByVal freeze As Boolean)
        Dim lstItem As New ListItem
        lstItem.Text = name
        Me.lForm.LayerList.Items.Add(lstItem)
        lstItem = New ListItem
        If visible Then
            lstItem.ImageIndex = 7
        Else
            lstItem.ImageIndex = 8
        End If
        Me.lForm.LayerList.Items.Add(lstItem)
        lstItem = New ListItem
        If freeze Then
            lstItem.ImageIndex = 3
        Else
            lstItem.ImageIndex = 4
        End If
        Me.lForm.LayerList.Items.Add(lstItem)
        lstItem = New ListItem
        lstItem.DrawColorRect = True
        lstItem.BackColor = color
        Me.lForm.LayerList.Items.Add(lstItem)
    End Sub

    ''' <summary>
    ''' Displays a form in which a user can add or delete the paths to the SHX files.
    ''' </summary>
    Public Sub AddSHXPaths()
        Me.shxFrm.ShowDialog()
        If Me.shxFrm.NeedReopen Then
            Me.ChangeTypeFont()
        End If
    End Sub

    ''' <summary>
    ''' Paints the CAD image background in the black color.
    ''' </summary>
    Public Sub Black_Click()
        Me.cadPictBox.BackColor = Color.Black
        Me.trvEntity.BackColor = Color.Black
        Me.trvEntity.ForeColor = Color.White
        If (Not Me.cadImageFld Is Nothing) Then
            Me.cadImageFld.DefaultColor = Color.White
            Me.cadImageFld.BackgroundColor = Color.Black
        End If
        If (Not Me.clipRectangle Is Nothing) Then
            Me.clipRectangle.Color = Color.White
        End If
    End Sub

    Private Sub cadPictBox_MouseDown(ByVal sender As System.Object, ByVal e As System.Windows.Forms.MouseEventArgs) Handles cadPictBox.MouseDown
        If (Not Me.cadImageFld Is Nothing) Then
            If ((e.Button = System.Windows.Forms.MouseButtons.Left) OrElse (e.Button = System.Windows.Forms.MouseButtons.Middle)) Then
                If ((Me.cadImageFld.SelectionMode = SelectionEntityMode.Enabled) AndAlso Me.useSelectEntity) Then
                    If Me.cadImageFld.Select(e.X, e.Y) Then
                        Me.cadPictBox.Invalidate(Me.cadImageFld.GetSelectEntityRegion(Me.cadPictBox.ClientRectangle))
                        Return
                    End If
                    Me.cadPictBox.Invalidate(Me.cadImageFld.GetSelectEntityRegion(Me.cadPictBox.ClientRectangle))
                End If
            ElseIf (e.Button = System.Windows.Forms.MouseButtons.Right) Then
                Form.ActiveForm.Cursor = Cursors.Hand
                Me.cX = e.X
                Me.cY = e.Y
                Me.detRMouseDown = True
                Return
            End If
            If ((Not Me.clipRectangle.Enabled AndAlso (Not Me.cadImageFld Is Nothing)) AndAlso Not Me.orb3D.Visible) Then
                Me.clipRectangle.EnableRect(RectangleType.Zooming, New Rectangle(e.X, e.Y, 0, 0))
            End If
        End If
    End Sub

    Private Sub cadPictBox_MouseMove(ByVal sender As System.Object, ByVal e As System.Windows.Forms.MouseEventArgs) Handles cadPictBox.MouseMove
        If Not Me.cadPictBox.Focused Then
            Me.cadPictBox.Focus()
        End If
        If (Not Me.cadImageFld Is Nothing) Then
            If (Me.detRMouseDown AndAlso Not Me.orb3D.Visible) Then
                Me.LeftImagePosition = (Me.LeftImagePosition - (Me.cX - e.X))
                Me.TopImagePosition = (Me.TopImagePosition - (Me.cY - e.Y))
                Me.cX = e.X
                Me.cY = e.Y
                Me.cadPictBox.Invalidate()                
            End If
            Me.PreviousPosition = New PointF(CSng(e.X), CSng(e.Y))
            Dim vPt As DPoint = Me.GetRealPoint(e.X, e.Y)
            Me.stBar.Panels.Item(2).Text = String.Concat(New String() {vPt.X.ToString, ApplicationConstants.sepstr2, vPt.Y.ToString, ApplicationConstants.sepstr2, vPt.Z.ToString})
        End If
    End Sub

    Private Sub cadPictBox_MouseUp(ByVal sender As System.Object, ByVal e As System.Windows.Forms.MouseEventArgs) Handles cadPictBox.MouseUp
        Me.detRMouseDown = False
        Me.cadPictBox.Cursor = Cursors.Default
        If ((((Me.clipRectangle.Enabled AndAlso (Me.clipRectangle.Type = RectangleType.Zooming)) AndAlso (Me.clipRectangle.ClientRectangle.Width > 5)) AndAlso (Me.clipRectangle.ClientRectangle.Height > 5)) AndAlso (Not Me.MultipleSelect AndAlso (Me.ImageScale <= 1000.0!))) Then
            Dim tmp1 As Single = (Me.visibleArea.Width / CSng(Me.clipRectangle.ClientRectangle.Width))
            Dim tmp2 As Single = (Me.visibleArea.Height / CSng(Me.clipRectangle.ClientRectangle.Height))
            If (tmp1 > tmp2) Then
                tmp1 = tmp2
            End If
            Me.LeftImagePosition = (Me.LeftImagePosition + (CSng(Me.clipRectangle.ClientRectangle.Width) / 2.0!))
            Me.TopImagePosition = (Me.TopImagePosition + (CSng(Me.clipRectangle.ClientRectangle.Height) / 2.0!))
            Me.Zoom(tmp1)
        End If
    End Sub

    Private Sub cadPictBox_Paint(ByVal sender As System.Object, ByVal e As System.Windows.Forms.PaintEventArgs) Handles cadPictBox.Paint
        If (Not Me.cadImageFld Is Nothing) Then
            Me.DrawCADImage(e.Graphics)
            Me.stBar.Panels.Item(1).Text = Me.RealScale
        End If
    End Sub

    Private Sub cadPictBox_Resize(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cadPictBox.Resize
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub CADPictBoxKeyDown(ByVal sender As System.Object, ByVal e As System.Windows.Forms.KeyEventArgs) Handles tlbTool.KeyDown
        If Not Me.cadPictBox.Focused Then
            Me.cadPictBox.Focus()
        End If
        Dim cn As Single = 10.0!
        If e.Shift Then
            cn = 20.0!
        End If
        Select Case e.KeyCode
            Case Keys.Left
                Me.LeftImagePosition = (Me.LeftImagePosition - cn)
                Me.cadPictBox.Invalidate()                
                Exit Select
            Case Keys.Up
                Me.TopImagePosition = (Me.TopImagePosition - cn)
                Me.cadPictBox.Invalidate()                
                Exit Select
            Case Keys.Right
                Me.LeftImagePosition = (Me.LeftImagePosition + cn)
                Me.cadPictBox.Invalidate()                
                Exit Select
            Case Keys.Down
                Me.TopImagePosition = (Me.TopImagePosition + cn)
                Me.cadPictBox.Invalidate()                
                Exit Select
        End Select
    End Sub

    Private Sub CADPictBoxMouseWheel(ByVal sender As Object, ByVal e As MouseEventArgs)
        If (e.Delta < 0) Then
            Me.Zoom(0.7!)
        Else
            Me.Zoom(1.3!)
        End If
        Me.Shift()        
    End Sub

    Private Sub CADPictBoxScroll(ByVal sender As Object, ByVal e As ScrollEventArgsExt)
        If (((e.NewValue = 0) AndAlso (e.OldValue = 0)) AndAlso (e.Type <> ScrollEventType.ThumbPosition)) Then
            e.NewValue = -5
        End If
        If (e.ScrollOrientation = CADImport.FaceModule.ScrollOrientation.VerticalScroll) Then
            Me.TopImagePosition = (Me.TopImagePosition - (e.NewValue - e.OldValue))
        End If
        If (e.ScrollOrientation = CADImport.FaceModule.ScrollOrientation.HorizontalScroll) Then
            Me.LeftImagePosition = (Me.LeftImagePosition - (e.NewValue - e.OldValue))
        End If
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub cbLayouts_SelectedIndexChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cbLayouts.SelectedIndexChanged
        Me.ChangeCurrLayoutIndex()
    End Sub

    ''' <summary>
    ''' Shows or hides 3D axes.
    ''' </summary>
    Public Sub Change3DAxesVisiblity()
        Me.cadImageFld.IsDraw3DAxes = Not Me.cadImageFld.IsDraw3DAxes
        Me.tlbAxes.Pushed = Me.cadImageFld.IsDraw3DAxes
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub ChangeBackColor(ByVal val As Boolean)
        If val Then
            Me.Black_Click()
        Else
            Me.White_Click()
        End If
    End Sub

    Private Sub ChangeControlState()
        Dim detNullImg As Boolean = (Not Me.cadImageFld Is Nothing)
        Me.EnableButton(detNullImg)
        Dim tmp As Boolean = False
        If (Me.cadPictBox.BackColor.Equals(Color.White)) Then
            tmp = True
        End If
        Me.miWhiteBackground.Checked = tmp
        Me.miBlackBackground.Checked = Not tmp
        If detNullImg Then
            Me.tlbWhite.Pushed = tmp
            Me.tlbBlack.Pushed = Not tmp
        Else
            Me.tlbWhite.Pushed = False
            Me.tlbBlack.Pushed = False
        End If
        tmp = Me.textVisible
        If detNullImg Then
            Me.tlbTextShow.Pushed = tmp
        Else
            Me.tlbTextShow.Pushed = False
        End If
        If Not tmp Then
            Me.tlbTextShow.ImageIndex = 15
        Else
            Me.tlbTextShow.ImageIndex = 14
        End If
        Me.miTextsShow.Checked = tmp
        tmp = Me.dimVisible
        If detNullImg Then
            Me.tlbDimShow.Pushed = tmp
        Else
            Me.tlbDimShow.Pushed = False
        End If
        If Not tmp Then
            Me.tlbDimShow.ImageIndex = &H11
        Else
            Me.tlbDimShow.ImageIndex = &H10
        End If
        Me.miDimShow.Checked = tmp
        tmp = Me.orb3D.Visible
        Me.tlb3d.Pushed = tmp
        Me.miEnable3DOrbit.Checked = tmp
        Me.miShowEntityTree.Checked = Me.trvEntity.Visible
        tmp = Me.drawMode
        If detNullImg Then
            Me.tlbBlackMode.Pushed = Not tmp
            Me.tlbColorMode.Pushed = tmp
        Else
            Me.tlbBlackMode.Pushed = False
            Me.tlbColorMode.Pushed = False
        End If
        Me.miDrawNormalColor.Checked = tmp
        Me.miDrawBlackColor.Checked = Not tmp
        tmp = Me.useWinEllipse
        If detNullImg Then
            Me.tlbArcPoly.Pushed = Not tmp
        Else
            Me.tlbArcPoly.Pushed = False
        End If
        Me.miArcsSplit.Checked = Not tmp
        Me.miShowLineWeight.Checked = Me.showLineWeight
        If (Me.curLngIndex < Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Count) Then
            Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Item(Me.curLngIndex).Checked = False
        End If
        If (Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Count > Me.curLngIndex) Then
            Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Item(Me.curLngIndex).Checked = True
        End If
        If detNullImg Then
            Me.tlbSelObject.Pushed = Me.useSelectEntity
        Else
            Me.tlbSelObject.Pushed = False
        End If
        If detNullImg Then
            Me.tlbSHX.Pushed = Me.useSHXFonts
        Else
            Me.tlbSHX.Pushed = False
        End If
        Me.tlbUseDoubleBuffering.Pushed = Me.useDoubleBuffering
        If Me.useDoubleBuffering Then
            Me.tlbUseDoubleBuffering.ImageIndex = &H1D
        Else
            Me.tlbUseDoubleBuffering.ImageIndex = 30
        End If
    End Sub

    ''' <summary>
    ''' Changes current layout in accordance with its new index in the list of layouts.
    ''' </summary>
    ''' <remarks>A list of layouts is located below the toolbar.</remarks>
    Public Sub ChangeCurrLayoutIndex()
        Me.cadImageFld.SetCurrentLayout(Me.cbLayouts.SelectedIndex)
        Me.DoResize()
        Me.ResetScaling()
        If (Me.cbLayouts.SelectedIndex <> 0) Then
            Me.tlbLay.Pushed = False
            Me.tlbLay.Enabled = False
            Me.orb3D.Visible = False
            Me.orb3D.Disable3dOrbit()
        Else
            Me.tlbLay.Enabled = True
        End If
    End Sub

    ''' <summary>
    ''' Shows or hides dimensions in the current CAD image.
    ''' </summary>
    Public Sub ChangeDimensionsVisiblity()
        Me.dimVisible = Not Me.dimVisible
        Me.cadImageFld.DimensionsVisible = Me.dimVisible
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub ChangeDoubleBufferingMode()
        If (Not Me.cadImageFld Is Nothing) Then
            If Me.useDoubleBuffering Then
                Me.useSelectEntity = False
                Me.cadImageFld.ClearSelection()
                Me.clipRectangle.MultySelect = False
                Me.showLineWeight = False
                Me.tlbSelObject.Pushed = False
            End If
            If (Me.cadImageFld.UseDoubleBuffering <> Me.useDoubleBuffering) Then
                Me.cadImageFld.UseDoubleBuffering = Me.useDoubleBuffering
                Me.cadPictBox.Invalidate()
            End If
        End If
    End Sub

    Private Sub ChangeDrawingColors(ByVal val As Boolean)
        If val Then
            Me.DoNormalColor()
        Else
            Me.DoBlackColor()
        End If
    End Sub

    Public Sub ChangeLanguage(ByVal val As String, ByVal index As Integer)
        Me.curLngIndex = index
        Me.lngFile = (val & ApplicationConstants.lngextstr)
        Me.SetAllFormsLanguageSettings()
        Me.SetLNG()
        Me.ChangeControlState()
    End Sub

    Private Sub ChangeSelectionCond(ByVal invalidate As Boolean)
        If Me.useSelectEntity Then
            Me.cadImageFld.SelectionMode = SelectionEntityMode.Enabled
            Me.clipRectangle.MultySelect = True
        Else
            Me.cadImageFld.SelectionMode = SelectionEntityMode.Disabled
            Me.clipRectangle.MultySelect = False
            Me.showLineWeight = False
        End If
        Me.useDoubleBuffering = (Not Me.useSelectEntity AndAlso Me.useDoubleBuffering)
        Me.ChangeDoubleBufferingMode()
        If invalidate Then
            Me.cadPictBox.Invalidate()
        End If
    End Sub

    ''' <summary>
    ''' Alternately changes a boolean value that indicates if a thickness of lines is determined by the file data.
    ''' </summary>
    Public Sub ChangeShowLineWeight()
        If (Not Me.showLineWeight AndAlso Me.cadImageFld.UseDoubleBuffering) Then
            Me.useDoubleBuffering = False
            Me.ChangeDoubleBufferingMode()
        End If
        Me.showLineWeight = Not Me.showLineWeight
        Me.cadImageFld.IsShowLineWeight = Me.showLineWeight
        Me.cadPictBox.Invalidate()
    End Sub

    ''' <summary>
    ''' Shows or hides texts in the current CAD image.
    ''' </summary>
    Public Sub ChangeTextsVisiblity()
        Me.textVisible = Not Me.textVisible
        Me.cadImageFld.TextVisible = Me.textVisible
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub ChangeTreeVisible(ByVal val As Boolean)
        Me.ChangeTreeVisiblity(val)
    End Sub

    ''' <summary>
    ''' Shows or hides a panel that contains the entities tree.
    ''' </summary>
    Public Sub ChangeTreeVisiblity(ByVal val As Boolean)
        If val Then
            CADImportFace.LoadTreeNodes(Me.trvEntity.Nodes, Me.cadImageFld)
        End If
        Me.trvPanel.Visible = val
        Me.spTree.Visible = val
    End Sub

    Private Sub ChangeTypeFont()
        Me.useSHXFonts = Not Me.useSHXFonts
        CADConst.UseSHXFonts = Me.useSHXFonts
        If Me.useSHXFonts Then
            Me.DoSHXFonts()
        Else
            Me.DoTTFFonts()
        End If
        If (Not Me.cadImageFld Is Nothing) Then
            Me.ReOpen()
        End If
    End Sub

    ''' <summary>
    ''' Closes a currently open CAD file.
    ''' </summary>
    Public Sub CloseFile()
        Me.cbLayouts.Items.Clear()
        Me.cadImageFld.Dispose()
        Me.cadImageFld = Nothing
        Me.propGrid.SelectedObject = Nothing
        Me.EnableButton(False)
        Me.trvEntity.Nodes.Clear()
        Me.cadPictBox.Invalidate()
        Me.lForm.LayerList.Clear()
    End Sub

    ''' <summary>
    ''' Paints the CAD image background in the user defined color.
    ''' </summary>
    Public Sub Color_Click()
        If (Me.dlgSetColor.ShowDialog = System.Windows.Forms.DialogResult.OK) Then
            Me.cadPictBox.BackColor = Me.dlgSetColor.Color
            If (Not Me.cadImageFld Is Nothing) Then
                Me.cadImageFld.BackgroundColor = Me.dlgSetColor.Color
            End If
        End If
    End Sub

    Friend Sub CreateNewImage()
        If (Not Me.cadImageFld Is Nothing) Then
            Me.cadImageFld.Dispose()
        End If
        Me.ImageScale = 1.0!
        Me.ImagePreviousScale = 1.0!
        Me.Position = New PointF
        Me.cadImageFld = New CADImage
        Me.cadImageFld.SelectionMode = SelectionEntityMode.Enabled
        Me.useDoubleBuffering = False
        Me.ChangeDoubleBufferingMode()
        If (Me.cadPictBox.BackColor.Equals(Color.White)) Then
            Me.White_Click()
        Else
            Me.Black_Click()
        End If
        Me.cadImageFld.InitialNewImage()
        Me.EnableButton(True)
        Me.trvEntity.Nodes.Clear()
        Me.DoResize()
        Me.cadPictBox.Invalidate()
        ObjEntity.cadImage = Me.cadImageFld
        ObjEntity.propGrid = Me.propGrid
        Me.cadImageFld.UseWinEllipse = False
        Me.prtForm.Image = Me.cadImageFld
        Me.cadImageFld.BackgroundColor = Me.cadPictBox.BackColor
    End Sub

    Private Sub CreateNewSettingsList()
        Dim tmp As String
        Me.settingsLst = New SortedList
        Me.settingsLst.Add(ApplicationConstants.languagepath, Me.mlng.Path)
        Me.settingsLst.Add(ApplicationConstants.languagestr, Me.lngFile)
        Me.settingsLst.Add(ApplicationConstants.languageIDstr, Me.curLngIndex)
        If (Me.cadPictBox.BackColor.Equals(Color.Black)) Then
            tmp = ApplicationConstants.blackstr
        Else
            tmp = ApplicationConstants.whitestr
        End If
        Me.settingsLst.Add(ApplicationConstants.backcolorstr, tmp)
        Me.settingsLst.Add(ApplicationConstants.showentitystr, Me.trvPanel.Visible)
        Me.settingsLst.Add(ApplicationConstants.drawmodestr, Me.drawMode)
        Dim cn As Integer = Me.shxFrm.lstDir.Items.Count
        Me.settingsLst.Add(ApplicationConstants.shxpathcnstr, Me.shxFrm.lstDir.Items.Count)
        Dim i As Integer
        For i = 0 To cn - 1
            Me.settingsLst.Add(String.Format("SHXPath_{0}", (i + 1)), Me.shxFrm.lstDir.Items.Item(i))
        Next i
        If (Protection.LicenseType = LicenseType.Floating) Then
            Me.settingsLst.Add(ApplicationConstants.typelcstr, ApplicationConstants.floatingstr)
            Me.settingsLst.Add(ApplicationConstants.hoststr, Me.floatLicFrm.Host)
            Me.settingsLst.Add(ApplicationConstants.portstr, Me.floatLicFrm.Port)
            Me.settingsLst.Add(ApplicationConstants.appconst, Me.floatLicFrm.App)
        Else
            Me.settingsLst.Add(ApplicationConstants.typelcstr, ApplicationConstants.registerstr)
        End If
        Me.optForm.SettingsList = Me.settingsLst
    End Sub

    Private Sub DeactCADImage()
        Me.propGrid.SelectedObject = Nothing
        Me.lForm.LayerList.Clear()
        RemoveHandler Me.lForm.LayerList.SelectItemEvent, Me.listItemSelectDel
    End Sub

    ''' <summary>
    ''' Cleans up any resources being used.
    ''' </summary>
    ''' <param name="disposing">A value indicating if both managed and unmanaged resources have to be released (<b>true</b>) or only unmanaged (<b>false</b>). 
    ''' </param>
    Protected Overloads Sub Dispose(ByVal disposing As Boolean)
        If (disposing AndAlso (Not Me.components Is Nothing)) Then
            Me.components.Dispose()
        End If
        MyBase.Dispose(disposing)
    End Sub

    ''' <summary>
    ''' Displays a CAD image in black and white colors.
    ''' </summary>
    Public Sub DoBlackColor()
        If (Not Me.cadImageFld Is Nothing) Then
            Me.cadImageFld.DrawMode = CADDrawMode.Black
            Me.drawMode = False
            Me.cadPictBox.Invalidate()
        End If
    End Sub

    Private Sub DoEnableRectangle(ByVal val As Boolean)
        If val Then
            Me.Go3dOrbit(False)
            Me.clipRectangle.Color = Me.cadImageFld.DefaultColor
            Me.clipRectangle.EnableRect(RectangleType.Selecting)
        Else
            Me.clipRectangle.DisableRect()
        End If
        Me.tlbRect.Pushed = val
    End Sub

    ''' <summary>
    ''' Displays a CAD image in all used colors.
    ''' </summary>
    Public Sub DoNormalColor()
        If (Not Me.cadImageFld Is Nothing) Then
            Me.cadImageFld.DrawMode = CADDrawMode.Normal
            Me.drawMode = True
            Me.cadPictBox.Invalidate()
        End If
    End Sub

    ''' <summary>
    ''' Resizes the CAD image to fit drawing's bounds.
    ''' </summary>
    ''' <remarks>This method is invoked when changing layout or working with a 3D Orbit tool.</remarks>
    Public Sub DoResize()
        If (Not Me.cadImageFld Is Nothing) Then
            Dim wh As Single = CSng((Me.cadImageFld.AbsWidth / Me.cadImageFld.AbsHeight))
            Dim new_wh As Single = (CSng(Me.cadPictBox.ClientRectangle.Width) / CSng(Me.cadPictBox.ClientRectangle.Height))
            If TypeOf Me.cadImageFld Is CADRasterImage Then
                Me.visibleArea = New SizeF(CSng(Me.cadImageFld.AbsWidth), CSng(Me.cadImageFld.AbsHeight))
            Else
                Me.visibleArea = New SizeF(Me.cadPictBox.Size.Width, Me.cadPictBox.Size.Height)
            End If
            If (new_wh > wh) Then
                Me.visibleArea.Width = (Me.visibleArea.Height * wh)
            ElseIf (new_wh < wh) Then
                Me.visibleArea.Height = (Me.visibleArea.Width / wh)
            Else
                Me.visibleArea = New SizeF(Me.cadPictBox.Size.Width, Me.cadPictBox.Size.Height)
            End If
            Me.LeftImagePosition = ((Me.cadPictBox.ClientRectangle.Width - Me.visibleArea.Width) / 2.0!)
            Me.TopImagePosition = ((Me.cadPictBox.ClientRectangle.Height - Me.visibleArea.Height) / 2.0!)
            Me.cadPictBox.Invalidate()
        End If
    End Sub

    Private Sub DoSHXFonts()
        CADConst.UseTTFFonts = False
        CADConst.UseMultyTTFFonts = False
    End Sub

    Private Sub DoTTFFonts()
        CADConst.UseTTFFonts = True
        CADConst.UseMultyTTFFonts = True
    End Sub

    ''' <summary>
    ''' Increases a scale of the CAD image in two times.
    ''' </summary>
    Public Sub DoZoomIn()
        If (Not Me.cadImageFld Is Nothing) Then
            Me.PreviousPosition = New PointF((CSng(Me.cadPictBox.ClientRectangle.Width) / 2.0!), (CSng(Me.cadPictBox.ClientRectangle.Height) / 2.0!))
            Me.ImageScale = (Me.ImageScale * 2.0!)
            Me.cadPictBox.Invalidate()
            Me.Shift()            
        End If
    End Sub

    ''' <summary>
    ''' Decreases a ImageScale of the CAD image in two times.
    ''' </summary>
    Public Sub DoZoomOut()
        If (Not Me.cadImageFld Is Nothing) Then
            Me.PreviousPosition = New PointF((CSng(Me.cadPictBox.ClientRectangle.Width) / 2.0!), (CSng(Me.cadPictBox.ClientRectangle.Height) / 2.0!))
            Me.ImageScale = (Me.ImageScale / 2.0!)
            Me.cadPictBox.Invalidate()
            Me.Shift()            
        End If
    End Sub

    ''' <summary>
    ''' Draws a CAD image from the loaded CAD file.
    ''' </summary>
    ''' <param name="gr">A <see cref="T:System.Drawing.Graphics">Graphics</see> object used to draw the CAD entities.</param>
    Public Sub DrawCADImage(ByVal gr As Graphics)
        Try
            Me.Shift()
            Dim tmp As RectangleF = Me.ImageRectangleF
            Me.SetSizePictureBox(New Size(CInt(tmp.Width), CInt(tmp.Height)))
            Me.SetPictureBoxPosition(Me.Position)
            Me.cadImageFld.Draw(gr, tmp)
        Catch e1 As Exception
            MessageBox.Show(String.Format("[{0}] {1}", e1.Message, e1.StackTrace))
        End Try
    End Sub

    ''' <summary>
    ''' Enables or disables buttons of the toolbar and menu items of the main menu.
    ''' </summary>
    ''' <param name="aVal"><b>true</b> if to enable the buttons and menu items; <b>false</b> if to disable them.</param>
    ''' <remarks>The buttons and menu items are enabled after loading a CAD file and become disabled after closing the file.</remarks>
    Public Sub EnableButton(ByVal aVal As Boolean)
        Dim i As Integer
        For i = 1 To &H18 - 1
            Me.tlbTool.Buttons.Item(i).Enabled = aVal
        Next i
        Me.cbLayouts.Enabled = aVal
        Me.miScale.Enabled = aVal
        Me.miSaveFile.Enabled = aVal
        Me.miCopyAsBMP.Enabled = aVal
        Me.miZoomIn.Enabled = aVal
        Me.miZoomOut.Enabled = aVal
        Me.miFitToWindow.Enabled = aVal
        Me.miDrawNormalColor.Enabled = aVal
        Me.miDrawBlackColor.Enabled = aVal
        Me.miWhiteBackground.Enabled = aVal
        Me.miBlackBackground.Enabled = aVal
        Me.miChangeBackgroundColor.Enabled = aVal
        Me.miShowLineWeight.Enabled = aVal
        Me.miArcsSplit.Enabled = aVal
        Me.miDimShow.Enabled = aVal
        Me.miTextsShow.Enabled = aVal
        Me.miLayersShow.Enabled = aVal
        Me.mi3DViews.Enabled = aVal
        Me.miEnable3DOrbit.Enabled = aVal
        Me.miClosePicture.Enabled = aVal
        Me.miPrint.Enabled = aVal
        Me.miPrintPreview.Enabled = aVal
        Me.miCustomPrint.Enabled = aVal
        Me.miSaveAsDXF.Enabled = aVal
    End Sub

    Friend Sub GetFromClipboard()
        If (Me.cadImageFld Is Nothing) Then
            Me.CreateNewImage()
        End If
        Dim img As Image = Me.GetImageFromClipboard
        If (Not img Is Nothing) Then
            Me.cadImageFld = New CADRasterImage
            DirectCast(Me.cadImageFld, CADRasterImage).LoadFromImage(img)
            If (Me.cadPictBox.BackColor.Equals(Color.White)) Then
                Me.White_Click()
            Else
                Me.Black_Click()
            End If
            Me.ResizeLayout()
        End If
    End Sub

    Private Function GetImageFromClipboard() As Image
        Dim objTmp As DataObject = DirectCast(Clipboard.GetDataObject, DataObject)
        Return DirectCast(objTmp.GetData(GetType(Bitmap)), Bitmap)
    End Function

    ''' <summary>
    ''' Gets a three-dimensional point of the current CAD image from the specified screen point.
    ''' </summary>
    ''' <param name="x">An X coordinate of the screen point.</param>
    ''' <param name="y">A Y coordinate of the screen point.</param>
    ''' <returns>A three-dimensional point.</returns>
    Friend Function GetRealPoint(ByVal x As Integer, ByVal y As Integer) As DPoint
        Dim tmpRect As RectangleF = Me.ImageRectangleF
        Return CADConst.GetRealPoint(x, y, Me.cadImageFld, tmpRect)
    End Function

    ''' <summary>
    ''' Alternately displays or hides a 3D Orbit tool.
    ''' </summary>
    Public Sub Go3dOrbit(ByVal val As Boolean)
        Me.orb3D.Visible = val
        Me.detRMouseDown = False
        If val Then
            Me.DoEnableRectangle(False)
            Me.orb3D.Enable3dOrbit()
        Else
            Me.orb3D.Disable3dOrbit()
        End If
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub InitExtParam()
        Me.Initial3DOrbit()
        Me.InitLng()
        Me.InitSettings()
        Me.SetAllFormsSettings()
        Me.clipRectangle = New ClipRect(Me.cadPictBox)
        Me.clipRectangle.MultySelect = False
        Me.miCopyAsBMP.Shortcut = Shortcut.CtrlC
        CADImportFace.EntityPropertyGrid = Me.propGrid
        AddHandler Me.cadPictBox.MouseWheel, New MouseEventHandler(AddressOf Me.CADPictBoxMouseWheel)
        AddHandler Me.cadPictBox.ScrollEvent, New CADImport.FaceModule.ScrollEventHandlerExt(AddressOf Me.CADPictBoxScroll)
    End Sub

    Private Sub Initial3DOrbit()
        Me.orb3D.Parent = Me.cadPictBox
    End Sub

#Region " Windows Form Designer generated code "
    ''' <summary>
    ''' Required method for Designer support - do not modify
    ''' the contents of this method with the code editor.
    ''' </summary>
    Private Sub InitializeComponent()
        Me.components = New System.ComponentModel.Container
        Dim resources As System.ComponentModel.ComponentResourceManager = New System.ComponentModel.ComponentResourceManager(GetType(MainForm))
        Me.dlgSaveImg = New System.Windows.Forms.SaveFileDialog
        Me.stBar = New System.Windows.Forms.StatusBar
        Me.sbOpen = New System.Windows.Forms.StatusBarPanel
        Me.sbScale = New System.Windows.Forms.StatusBarPanel
        Me.sbCoord = New System.Windows.Forms.StatusBarPanel
        Me.mainMenu = New System.Windows.Forms.MainMenu(Me.components)
        Me.miFile = New System.Windows.Forms.MenuItem
        Me.miOpenFile = New System.Windows.Forms.MenuItem
        Me.miOpenFromWeb = New System.Windows.Forms.MenuItem
        Me.miSaveFile = New System.Windows.Forms.MenuItem
        Me.miSaveAsDXF = New System.Windows.Forms.MenuItem
        Me.miPrint = New System.Windows.Forms.MenuItem
        Me.miCustomPrint = New System.Windows.Forms.MenuItem
        Me.miPrintPreview = New System.Windows.Forms.MenuItem
        Me.miClosePicture = New System.Windows.Forms.MenuItem
        Me.miSeparator1 = New System.Windows.Forms.MenuItem
        Me.miExit = New System.Windows.Forms.MenuItem
        Me.editMenuItem = New System.Windows.Forms.MenuItem
        Me.miCopyAsBMP = New System.Windows.Forms.MenuItem
        Me.mView = New System.Windows.Forms.MenuItem
        Me.miShowEntityTree = New System.Windows.Forms.MenuItem
        Me.miSeparator2 = New System.Windows.Forms.MenuItem
        Me.miZoomIn = New System.Windows.Forms.MenuItem
        Me.miZoomOut = New System.Windows.Forms.MenuItem
        Me.miScale = New System.Windows.Forms.MenuItem
        Me.miZoom10 = New System.Windows.Forms.MenuItem
        Me.miZoom25 = New System.Windows.Forms.MenuItem
        Me.miZoom50 = New System.Windows.Forms.MenuItem
        Me.miZoom100 = New System.Windows.Forms.MenuItem
        Me.miZoom200 = New System.Windows.Forms.MenuItem
        Me.miZoom400 = New System.Windows.Forms.MenuItem
        Me.miZoom800 = New System.Windows.Forms.MenuItem
        Me.miFitToWindow = New System.Windows.Forms.MenuItem
        Me.miSeparator3 = New System.Windows.Forms.MenuItem
        Me.miShowShxForm = New System.Windows.Forms.MenuItem
        Me.miShowOptionsForm = New System.Windows.Forms.MenuItem
        Me.cADFilesMenuItem = New System.Windows.Forms.MenuItem
        Me.miDrawNormalColor = New System.Windows.Forms.MenuItem
        Me.miDrawBlackColor = New System.Windows.Forms.MenuItem
        Me.miWhiteBackground = New System.Windows.Forms.MenuItem
        Me.miBlackBackground = New System.Windows.Forms.MenuItem
        Me.miChangeBackgroundColor = New System.Windows.Forms.MenuItem
        Me.miSeparator4 = New System.Windows.Forms.MenuItem
        Me.miShowLineWeight = New System.Windows.Forms.MenuItem
        Me.miArcsSplit = New System.Windows.Forms.MenuItem
        Me.miDimShow = New System.Windows.Forms.MenuItem
        Me.miTextsShow = New System.Windows.Forms.MenuItem
        Me.miSeparator5 = New System.Windows.Forms.MenuItem
        Me.miLayersShow = New System.Windows.Forms.MenuItem
        Me.mi3DViews = New System.Windows.Forms.MenuItem
        Me.miInitialView = New System.Windows.Forms.MenuItem
        Me.miTopView = New System.Windows.Forms.MenuItem
        Me.miBottomView = New System.Windows.Forms.MenuItem
        Me.miLeftView = New System.Windows.Forms.MenuItem
        Me.miRightView = New System.Windows.Forms.MenuItem
        Me.miFrontView = New System.Windows.Forms.MenuItem
        Me.miBackView = New System.Windows.Forms.MenuItem
        Me.miSWIsometricView = New System.Windows.Forms.MenuItem
        Me.miSEIsometricView = New System.Windows.Forms.MenuItem
        Me.miNEIsometricView = New System.Windows.Forms.MenuItem
        Me.miNWIsometricView = New System.Windows.Forms.MenuItem
        Me.miEnable3DOrbit = New System.Windows.Forms.MenuItem
        Me.helpMenuItem = New System.Windows.Forms.MenuItem
        Me.miLanguages = New System.Windows.Forms.MenuItem
        Me.miRegistration = New System.Windows.Forms.MenuItem
        Me.miFloatLic = New System.Windows.Forms.MenuItem
        Me.miAbout = New System.Windows.Forms.MenuItem
        Me.dlgSetColor = New System.Windows.Forms.ColorDialog
        Me.tlbTool = New System.Windows.Forms.ToolBar
        Me.tlbOpen = New System.Windows.Forms.ToolBarButton
        Me.tlbZoomIn = New System.Windows.Forms.ToolBarButton
        Me.tlbZoomOut = New System.Windows.Forms.ToolBarButton
        Me.tlbSave = New System.Windows.Forms.ToolBarButton
        Me.tlbWhite = New System.Windows.Forms.ToolBarButton
        Me.tlbBlack = New System.Windows.Forms.ToolBarButton
        Me.tlbColor = New System.Windows.Forms.ToolBarButton
        Me.tlb3d = New System.Windows.Forms.ToolBarButton
        Me.menuOrbitView = New System.Windows.Forms.ContextMenu
        Me.miInitialOrbitView = New System.Windows.Forms.MenuItem
        Me.miTopOrbitView = New System.Windows.Forms.MenuItem
        Me.miBottomOrbitView = New System.Windows.Forms.MenuItem
        Me.miLeftOrbitView = New System.Windows.Forms.MenuItem
        Me.miRightOrbitView = New System.Windows.Forms.MenuItem
        Me.miFrontOrbitView = New System.Windows.Forms.MenuItem
        Me.miBackOrbitView = New System.Windows.Forms.MenuItem
        Me.miSWOrbitView = New System.Windows.Forms.MenuItem
        Me.miSEOrbitView = New System.Windows.Forms.MenuItem
        Me.miNEOrbitView = New System.Windows.Forms.MenuItem
        Me.miNWOrbitView = New System.Windows.Forms.MenuItem
        Me.tlbRotateLeft = New System.Windows.Forms.ToolBarButton
        Me.tlbRotateRight = New System.Windows.Forms.ToolBarButton
        Me.tlbRotateAngle = New System.Windows.Forms.ToolBarButton
        Me.tlbLay = New System.Windows.Forms.ToolBarButton
        Me.tlbArcPoly = New System.Windows.Forms.ToolBarButton
        Me.tlbBlackMode = New System.Windows.Forms.ToolBarButton
        Me.tlbColorMode = New System.Windows.Forms.ToolBarButton
        Me.tlbDefSize = New System.Windows.Forms.ToolBarButton
        Me.tlbTextShow = New System.Windows.Forms.ToolBarButton
        Me.tlbDimShow = New System.Windows.Forms.ToolBarButton
        Me.tlbSaveImageClip = New System.Windows.Forms.ToolBarButton
        Me.tlbPrint = New System.Windows.Forms.ToolBarButton
        Me.tlbSHX = New System.Windows.Forms.ToolBarButton
        Me.tlbRect = New System.Windows.Forms.ToolBarButton
        Me.tlbSelObject = New System.Windows.Forms.ToolBarButton
        Me.tlbAxes = New System.Windows.Forms.ToolBarButton
        Me.tlbOpenFromClipboard = New System.Windows.Forms.ToolBarButton
        Me.tlbUseDoubleBuffering = New System.Windows.Forms.ToolBarButton
        Me.imgLstToolBtn = New System.Windows.Forms.ImageList(Me.components)
        Me.pnlLayouts = New System.Windows.Forms.Panel
        Me.lbLayouts = New System.Windows.Forms.Label
        Me.cbLayouts = New System.Windows.Forms.ComboBox
        Me.trvPanel = New System.Windows.Forms.Panel
        Me.trvEntity = New System.Windows.Forms.TreeView
        Me.spPropGrid = New System.Windows.Forms.Splitter
        Me.propGrid = New System.Windows.Forms.PropertyGrid
        Me.spTree = New System.Windows.Forms.Splitter
        Me.printPrevDlg = New System.Windows.Forms.PrintPreviewDialog
        Me.dlgSaveDXF = New System.Windows.Forms.SaveFileDialog
        Me.cadPictBox = New CADImport.FaceModule.CADPictureBox
        Me.dlgOpenSerializeFile = New System.Windows.Forms.OpenFileDialog
        Me.dlgSaveSerializeFile = New System.Windows.Forms.SaveFileDialog
        Me.dlgOpenFile = New System.Windows.Forms.OpenFileDialog
        CType(Me.sbOpen, System.ComponentModel.ISupportInitialize).BeginInit()
        CType(Me.sbScale, System.ComponentModel.ISupportInitialize).BeginInit()
        CType(Me.sbCoord, System.ComponentModel.ISupportInitialize).BeginInit()
        Me.pnlLayouts.SuspendLayout()
        Me.trvPanel.SuspendLayout()
        CType(Me.cadPictBox, System.ComponentModel.ISupportInitialize).BeginInit()
        Me.SuspendLayout()
        '
        'dlgSaveImg
        '
        resources.ApplyResources(Me.dlgSaveImg, "dlgSaveImg")
        Me.dlgSaveImg.RestoreDirectory = True
        '
        'stBar
        '
        resources.ApplyResources(Me.stBar, "stBar")
        Me.stBar.Name = "stBar"
        Me.stBar.Panels.AddRange(New System.Windows.Forms.StatusBarPanel() {Me.sbOpen, Me.sbScale, Me.sbCoord})
        Me.stBar.ShowPanels = True
        '
        'sbOpen
        '
        Me.sbOpen.AutoSize = System.Windows.Forms.StatusBarPanelAutoSize.Contents
        resources.ApplyResources(Me.sbOpen, "sbOpen")
        '
        'sbScale
        '
        Me.sbScale.AutoSize = System.Windows.Forms.StatusBarPanelAutoSize.Contents
        resources.ApplyResources(Me.sbScale, "sbScale")
        '
        'sbCoord
        '
        resources.ApplyResources(Me.sbCoord, "sbCoord")
        Me.sbCoord.AutoSize = System.Windows.Forms.StatusBarPanelAutoSize.Contents
        '
        'mainMenu
        '
        Me.mainMenu.MenuItems.AddRange(New System.Windows.Forms.MenuItem() {Me.miFile, Me.editMenuItem, Me.mView, Me.cADFilesMenuItem, Me.helpMenuItem})
        '
        'miFile
        '
        Me.miFile.Index = 0
        Me.miFile.MenuItems.AddRange(New System.Windows.Forms.MenuItem() {Me.miOpenFile, Me.miOpenFromWeb, Me.miSaveFile, Me.miSaveAsDXF, Me.miPrint, Me.miCustomPrint, Me.miPrintPreview, Me.miClosePicture, Me.miSeparator1, Me.miExit})
        resources.ApplyResources(Me.miFile, "miFile")
        '
        'miOpenFile
        '
        Me.miOpenFile.Index = 0
        resources.ApplyResources(Me.miOpenFile, "miOpenFile")
        '
        'miOpenFromWeb
        '
        Me.miOpenFromWeb.Index = 1
        resources.ApplyResources(Me.miOpenFromWeb, "miOpenFromWeb")
        '
        'miSaveFile
        '
        resources.ApplyResources(Me.miSaveFile, "miSaveFile")
        Me.miSaveFile.Index = 2
        '
        'miSaveAsDXF
        '
        resources.ApplyResources(Me.miSaveAsDXF, "miSaveAsDXF")
        Me.miSaveAsDXF.Index = 3
        '
        'miPrint
        '
        resources.ApplyResources(Me.miPrint, "miPrint")
        Me.miPrint.Index = 4
        '
        'miCustomPrint
        '
        resources.ApplyResources(Me.miCustomPrint, "miCustomPrint")
        Me.miCustomPrint.Index = 5
        '
        'miPrintPreview
        '
        resources.ApplyResources(Me.miPrintPreview, "miPrintPreview")
        Me.miPrintPreview.Index = 6
        '
        'miClosePicture
        '
        resources.ApplyResources(Me.miClosePicture, "miClosePicture")
        Me.miClosePicture.Index = 7
        '
        'miSeparator1
        '
        Me.miSeparator1.Index = 8
        resources.ApplyResources(Me.miSeparator1, "miSeparator1")
        '
        'miExit
        '
        Me.miExit.Index = 9
        resources.ApplyResources(Me.miExit, "miExit")
        '
        'editMenuItem
        '
        Me.editMenuItem.Index = 1
        Me.editMenuItem.MenuItems.AddRange(New System.Windows.Forms.MenuItem() {Me.miCopyAsBMP})
        resources.ApplyResources(Me.editMenuItem, "editMenuItem")
        '
        'miCopyAsBMP
        '
        resources.ApplyResources(Me.miCopyAsBMP, "miCopyAsBMP")
        Me.miCopyAsBMP.Index = 0
        '
        'mView
        '
        Me.mView.Index = 2
        Me.mView.MenuItems.AddRange(New System.Windows.Forms.MenuItem() {Me.miShowEntityTree, Me.miSeparator2, Me.miZoomIn, Me.miZoomOut, Me.miScale, Me.miFitToWindow, Me.miSeparator3, Me.miShowShxForm, Me.miShowOptionsForm})
        resources.ApplyResources(Me.mView, "mView")
        '
        'miShowEntityTree
        '
        Me.miShowEntityTree.Checked = True
        Me.miShowEntityTree.Index = 0
        resources.ApplyResources(Me.miShowEntityTree, "miShowEntityTree")
        '
        'miSeparator2
        '
        Me.miSeparator2.Index = 1
        resources.ApplyResources(Me.miSeparator2, "miSeparator2")
        '
        'miZoomIn
        '
        resources.ApplyResources(Me.miZoomIn, "miZoomIn")
        Me.miZoomIn.Index = 2
        '
        'miZoomOut
        '
        resources.ApplyResources(Me.miZoomOut, "miZoomOut")
        Me.miZoomOut.Index = 3
        '
        'miScale
        '
        resources.ApplyResources(Me.miScale, "miScale")
        Me.miScale.Index = 4
        Me.miScale.MenuItems.AddRange(New System.Windows.Forms.MenuItem() {Me.miZoom10, Me.miZoom25, Me.miZoom50, Me.miZoom100, Me.miZoom200, Me.miZoom400, Me.miZoom800})
        '
        'miZoom10
        '
        Me.miZoom10.Index = 0
        resources.ApplyResources(Me.miZoom10, "miZoom10")
        '
        'miZoom25
        '
        Me.miZoom25.Index = 1
        resources.ApplyResources(Me.miZoom25, "miZoom25")
        '
        'miZoom50
        '
        Me.miZoom50.Index = 2
        resources.ApplyResources(Me.miZoom50, "miZoom50")
        '
        'miZoom100
        '
        Me.miZoom100.Index = 3
        resources.ApplyResources(Me.miZoom100, "miZoom100")
        '
        'miZoom200
        '
        Me.miZoom200.Index = 4
        resources.ApplyResources(Me.miZoom200, "miZoom200")
        '
        'miZoom400
        '
        Me.miZoom400.Index = 5
        resources.ApplyResources(Me.miZoom400, "miZoom400")
        '
        'miZoom800
        '
        Me.miZoom800.Index = 6
        resources.ApplyResources(Me.miZoom800, "miZoom800")
        '
        'miFitToWindow
        '
        resources.ApplyResources(Me.miFitToWindow, "miFitToWindow")
        Me.miFitToWindow.Index = 5
        '
        'miSeparator3
        '
        Me.miSeparator3.Index = 6
        resources.ApplyResources(Me.miSeparator3, "miSeparator3")
        '
        'miShowShxForm
        '
        Me.miShowShxForm.Index = 7
        resources.ApplyResources(Me.miShowShxForm, "miShowShxForm")
        '
        'miShowOptionsForm
        '
        Me.miShowOptionsForm.Index = 8
        resources.ApplyResources(Me.miShowOptionsForm, "miShowOptionsForm")
        '
        'cADFilesMenuItem
        '
        Me.cADFilesMenuItem.Index = 3
        Me.cADFilesMenuItem.MenuItems.AddRange(New System.Windows.Forms.MenuItem() {Me.miDrawNormalColor, Me.miDrawBlackColor, Me.miWhiteBackground, Me.miBlackBackground, Me.miChangeBackgroundColor, Me.miSeparator4, Me.miShowLineWeight, Me.miArcsSplit, Me.miDimShow, Me.miTextsShow, Me.miSeparator5, Me.miLayersShow, Me.mi3DViews, Me.miEnable3DOrbit})
        resources.ApplyResources(Me.cADFilesMenuItem, "cADFilesMenuItem")
        '
        'miDrawNormalColor
        '
        Me.miDrawNormalColor.Checked = True
        resources.ApplyResources(Me.miDrawNormalColor, "miDrawNormalColor")
        Me.miDrawNormalColor.Index = 0
        Me.miDrawNormalColor.RadioCheck = True
        '
        'miDrawBlackColor
        '
        resources.ApplyResources(Me.miDrawBlackColor, "miDrawBlackColor")
        Me.miDrawBlackColor.Index = 1
        Me.miDrawBlackColor.RadioCheck = True
        '
        'miWhiteBackground
        '
        resources.ApplyResources(Me.miWhiteBackground, "miWhiteBackground")
        Me.miWhiteBackground.Index = 2
        Me.miWhiteBackground.RadioCheck = True
        '
        'miBlackBackground
        '
        resources.ApplyResources(Me.miBlackBackground, "miBlackBackground")
        Me.miBlackBackground.Index = 3
        Me.miBlackBackground.RadioCheck = True
        '
        'miChangeBackgroundColor
        '
        resources.ApplyResources(Me.miChangeBackgroundColor, "miChangeBackgroundColor")
        Me.miChangeBackgroundColor.Index = 4
        '
        'miSeparator4
        '
        Me.miSeparator4.Index = 5
        resources.ApplyResources(Me.miSeparator4, "miSeparator4")
        '
        'miShowLineWeight
        '
        Me.miShowLineWeight.Checked = True
        resources.ApplyResources(Me.miShowLineWeight, "miShowLineWeight")
        Me.miShowLineWeight.Index = 6
        '
        'miArcsSplit
        '
        Me.miArcsSplit.Checked = True
        resources.ApplyResources(Me.miArcsSplit, "miArcsSplit")
        Me.miArcsSplit.Index = 7
        '
        'miDimShow
        '
        Me.miDimShow.Checked = True
        resources.ApplyResources(Me.miDimShow, "miDimShow")
        Me.miDimShow.Index = 8
        '
        'miTextsShow
        '
        Me.miTextsShow.Checked = True
        resources.ApplyResources(Me.miTextsShow, "miTextsShow")
        Me.miTextsShow.Index = 9
        '
        'miSeparator5
        '
        Me.miSeparator5.Index = 10
        resources.ApplyResources(Me.miSeparator5, "miSeparator5")
        '
        'miLayersShow
        '
        resources.ApplyResources(Me.miLayersShow, "miLayersShow")
        Me.miLayersShow.Index = 11
        '
        'mi3DViews
        '
        resources.ApplyResources(Me.mi3DViews, "mi3DViews")
        Me.mi3DViews.Index = 12
        Me.mi3DViews.MenuItems.AddRange(New System.Windows.Forms.MenuItem() {Me.miInitialView, Me.miTopView, Me.miBottomView, Me.miLeftView, Me.miRightView, Me.miFrontView, Me.miBackView, Me.miSWIsometricView, Me.miSEIsometricView, Me.miNEIsometricView, Me.miNWIsometricView})
        '
        'miInitialView
        '
        Me.miInitialView.Index = 0
        resources.ApplyResources(Me.miInitialView, "miInitialView")
        '
        'miTopView
        '
        Me.miTopView.Index = 1
        resources.ApplyResources(Me.miTopView, "miTopView")
        '
        'miBottomView
        '
        Me.miBottomView.Index = 2
        resources.ApplyResources(Me.miBottomView, "miBottomView")
        '
        'miLeftView
        '
        Me.miLeftView.Index = 3
        resources.ApplyResources(Me.miLeftView, "miLeftView")
        '
        'miRightView
        '
        Me.miRightView.Index = 4
        resources.ApplyResources(Me.miRightView, "miRightView")
        '
        'miFrontView
        '
        Me.miFrontView.Index = 5
        resources.ApplyResources(Me.miFrontView, "miFrontView")
        '
        'miBackView
        '
        Me.miBackView.Index = 6
        resources.ApplyResources(Me.miBackView, "miBackView")
        '
        'miSWIsometricView
        '
        Me.miSWIsometricView.Index = 7
        resources.ApplyResources(Me.miSWIsometricView, "miSWIsometricView")
        '
        'miSEIsometricView
        '
        Me.miSEIsometricView.Index = 8
        resources.ApplyResources(Me.miSEIsometricView, "miSEIsometricView")
        '
        'miNEIsometricView
        '
        Me.miNEIsometricView.Index = 9
        resources.ApplyResources(Me.miNEIsometricView, "miNEIsometricView")
        '
        'miNWIsometricView
        '
        Me.miNWIsometricView.Index = 10
        resources.ApplyResources(Me.miNWIsometricView, "miNWIsometricView")
        '
        'miEnable3DOrbit
        '
        resources.ApplyResources(Me.miEnable3DOrbit, "miEnable3DOrbit")
        Me.miEnable3DOrbit.Index = 13
        '
        'helpMenuItem
        '
        Me.helpMenuItem.Index = 4
        Me.helpMenuItem.MenuItems.AddRange(New System.Windows.Forms.MenuItem() {Me.miLanguages, Me.miRegistration, Me.miFloatLic, Me.miAbout})
        resources.ApplyResources(Me.helpMenuItem, "helpMenuItem")
        '
        'miLanguages
        '
        Me.miLanguages.Index = 0
        resources.ApplyResources(Me.miLanguages, "miLanguages")
        '
        'miRegistration
        '
        Me.miRegistration.Index = 1
        resources.ApplyResources(Me.miRegistration, "miRegistration")
        '
        'miFloatLic
        '
        Me.miFloatLic.Index = 2
        resources.ApplyResources(Me.miFloatLic, "miFloatLic")
        '
        'miAbout
        '
        Me.miAbout.Index = 3
        resources.ApplyResources(Me.miAbout, "miAbout")
        '
        'tlbTool
        '
        resources.ApplyResources(Me.tlbTool, "tlbTool")
        Me.tlbTool.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle
        Me.tlbTool.Buttons.AddRange(New System.Windows.Forms.ToolBarButton() {Me.tlbOpen, Me.tlbZoomIn, Me.tlbZoomOut, Me.tlbSave, Me.tlbWhite, Me.tlbBlack, Me.tlbColor, Me.tlb3d, Me.tlbRotateLeft, Me.tlbRotateRight, Me.tlbRotateAngle, Me.tlbLay, Me.tlbArcPoly, Me.tlbBlackMode, Me.tlbColorMode, Me.tlbDefSize, Me.tlbTextShow, Me.tlbDimShow, Me.tlbSaveImageClip, Me.tlbPrint, Me.tlbSHX, Me.tlbRect, Me.tlbSelObject, Me.tlbAxes, Me.tlbOpenFromClipboard, Me.tlbUseDoubleBuffering})
        Me.tlbTool.ImageList = Me.imgLstToolBtn
        Me.tlbTool.Name = "tlbTool"
        '
        'tlbOpen
        '
        resources.ApplyResources(Me.tlbOpen, "tlbOpen")
        Me.tlbOpen.Name = "tlbOpen"
        '
        'tlbZoomIn
        '
        resources.ApplyResources(Me.tlbZoomIn, "tlbZoomIn")
        Me.tlbZoomIn.Name = "tlbZoomIn"
        '
        'tlbZoomOut
        '
        resources.ApplyResources(Me.tlbZoomOut, "tlbZoomOut")
        Me.tlbZoomOut.Name = "tlbZoomOut"
        '
        'tlbSave
        '
        resources.ApplyResources(Me.tlbSave, "tlbSave")
        Me.tlbSave.Name = "tlbSave"
        '
        'tlbWhite
        '
        resources.ApplyResources(Me.tlbWhite, "tlbWhite")
        Me.tlbWhite.Name = "tlbWhite"
        '
        'tlbBlack
        '
        resources.ApplyResources(Me.tlbBlack, "tlbBlack")
        Me.tlbBlack.Name = "tlbBlack"
        '
        'tlbColor
        '
        resources.ApplyResources(Me.tlbColor, "tlbColor")
        Me.tlbColor.Name = "tlbColor"
        '
        'tlb3d
        '
        Me.tlb3d.DropDownMenu = Me.menuOrbitView
        resources.ApplyResources(Me.tlb3d, "tlb3d")
        Me.tlb3d.Name = "tlb3d"
        Me.tlb3d.Style = System.Windows.Forms.ToolBarButtonStyle.DropDownButton
        '
        'menuOrbitView
        '
        Me.menuOrbitView.MenuItems.AddRange(New System.Windows.Forms.MenuItem() {Me.miInitialOrbitView, Me.miTopOrbitView, Me.miBottomOrbitView, Me.miLeftOrbitView, Me.miRightOrbitView, Me.miFrontOrbitView, Me.miBackOrbitView, Me.miSWOrbitView, Me.miSEOrbitView, Me.miNEOrbitView, Me.miNWOrbitView})
        '
        'miInitialOrbitView
        '
        Me.miInitialOrbitView.Index = 0
        resources.ApplyResources(Me.miInitialOrbitView, "miInitialOrbitView")
        '
        'miTopOrbitView
        '
        Me.miTopOrbitView.Index = 1
        resources.ApplyResources(Me.miTopOrbitView, "miTopOrbitView")
        '
        'miBottomOrbitView
        '
        Me.miBottomOrbitView.Index = 2
        resources.ApplyResources(Me.miBottomOrbitView, "miBottomOrbitView")
        '
        'miLeftOrbitView
        '
        Me.miLeftOrbitView.Index = 3
        resources.ApplyResources(Me.miLeftOrbitView, "miLeftOrbitView")
        '
        'miRightOrbitView
        '
        Me.miRightOrbitView.Index = 4
        resources.ApplyResources(Me.miRightOrbitView, "miRightOrbitView")
        '
        'miFrontOrbitView
        '
        Me.miFrontOrbitView.Index = 5
        resources.ApplyResources(Me.miFrontOrbitView, "miFrontOrbitView")
        '
        'miBackOrbitView
        '
        Me.miBackOrbitView.Index = 6
        resources.ApplyResources(Me.miBackOrbitView, "miBackOrbitView")
        '
        'miSWOrbitView
        '
        Me.miSWOrbitView.Index = 7
        resources.ApplyResources(Me.miSWOrbitView, "miSWOrbitView")
        '
        'miSEOrbitView
        '
        Me.miSEOrbitView.Index = 8
        resources.ApplyResources(Me.miSEOrbitView, "miSEOrbitView")
        '
        'miNEOrbitView
        '
        Me.miNEOrbitView.Index = 9
        resources.ApplyResources(Me.miNEOrbitView, "miNEOrbitView")
        '
        'miNWOrbitView
        '
        Me.miNWOrbitView.Index = 10
        resources.ApplyResources(Me.miNWOrbitView, "miNWOrbitView")
        '
        'tlbRotateLeft
        '
        resources.ApplyResources(Me.tlbRotateLeft, "tlbRotateLeft")
        Me.tlbRotateLeft.Name = "tlbRotateLeft"
        '
        'tlbRotateRight
        '
        resources.ApplyResources(Me.tlbRotateRight, "tlbRotateRight")
        Me.tlbRotateRight.Name = "tlbRotateRight"
        '
        'tlbRotateAngle
        '
        resources.ApplyResources(Me.tlbRotateAngle, "tlbRotateAngle")
        Me.tlbRotateAngle.Name = "tlbRotateAngle"
        '
        'tlbLay
        '
        resources.ApplyResources(Me.tlbLay, "tlbLay")
        Me.tlbLay.Name = "tlbLay"
        '
        'tlbArcPoly
        '
        resources.ApplyResources(Me.tlbArcPoly, "tlbArcPoly")
        Me.tlbArcPoly.Name = "tlbArcPoly"
        Me.tlbArcPoly.Style = System.Windows.Forms.ToolBarButtonStyle.ToggleButton
        Me.tlbArcPoly.Tag = ""
        '
        'tlbBlackMode
        '
        resources.ApplyResources(Me.tlbBlackMode, "tlbBlackMode")
        Me.tlbBlackMode.Name = "tlbBlackMode"
        Me.tlbBlackMode.Style = System.Windows.Forms.ToolBarButtonStyle.ToggleButton
        '
        'tlbColorMode
        '
        resources.ApplyResources(Me.tlbColorMode, "tlbColorMode")
        Me.tlbColorMode.Name = "tlbColorMode"
        Me.tlbColorMode.Style = System.Windows.Forms.ToolBarButtonStyle.ToggleButton
        '
        'tlbDefSize
        '
        resources.ApplyResources(Me.tlbDefSize, "tlbDefSize")
        Me.tlbDefSize.Name = "tlbDefSize"
        '
        'tlbTextShow
        '
        resources.ApplyResources(Me.tlbTextShow, "tlbTextShow")
        Me.tlbTextShow.Name = "tlbTextShow"
        '
        'tlbDimShow
        '
        resources.ApplyResources(Me.tlbDimShow, "tlbDimShow")
        Me.tlbDimShow.Name = "tlbDimShow"
        '
        'tlbSaveImageClip
        '
        resources.ApplyResources(Me.tlbSaveImageClip, "tlbSaveImageClip")
        Me.tlbSaveImageClip.Name = "tlbSaveImageClip"
        '
        'tlbPrint
        '
        resources.ApplyResources(Me.tlbPrint, "tlbPrint")
        Me.tlbPrint.Name = "tlbPrint"
        '
        'tlbSHX
        '
        resources.ApplyResources(Me.tlbSHX, "tlbSHX")
        Me.tlbSHX.Name = "tlbSHX"
        '
        'tlbRect
        '
        resources.ApplyResources(Me.tlbRect, "tlbRect")
        Me.tlbRect.Name = "tlbRect"
        '
        'tlbSelObject
        '
        resources.ApplyResources(Me.tlbSelObject, "tlbSelObject")
        Me.tlbSelObject.Name = "tlbSelObject"
        '
        'tlbAxes
        '
        resources.ApplyResources(Me.tlbAxes, "tlbAxes")
        Me.tlbAxes.Name = "tlbAxes"
        '
        'tlbOpenFromClipboard
        '
        resources.ApplyResources(Me.tlbOpenFromClipboard, "tlbOpenFromClipboard")
        Me.tlbOpenFromClipboard.Name = "tlbOpenFromClipboard"
        '
        'tlbUseDoubleBuffering
        '
        resources.ApplyResources(Me.tlbUseDoubleBuffering, "tlbUseDoubleBuffering")
        Me.tlbUseDoubleBuffering.Name = "tlbUseDoubleBuffering"
        Me.tlbUseDoubleBuffering.Pushed = True
        '
        'imgLstToolBtn
        '
        Me.imgLstToolBtn.ImageStream = CType(resources.GetObject("imgLstToolBtn.ImageStream"), System.Windows.Forms.ImageListStreamer)
        Me.imgLstToolBtn.TransparentColor = System.Drawing.Color.Magenta
        Me.imgLstToolBtn.Images.SetKeyName(0, "")
        Me.imgLstToolBtn.Images.SetKeyName(1, "")
        Me.imgLstToolBtn.Images.SetKeyName(2, "")
        Me.imgLstToolBtn.Images.SetKeyName(3, "")
        Me.imgLstToolBtn.Images.SetKeyName(4, "")
        Me.imgLstToolBtn.Images.SetKeyName(5, "")
        Me.imgLstToolBtn.Images.SetKeyName(6, "")
        Me.imgLstToolBtn.Images.SetKeyName(7, "")
        Me.imgLstToolBtn.Images.SetKeyName(8, "")
        Me.imgLstToolBtn.Images.SetKeyName(9, "")
        Me.imgLstToolBtn.Images.SetKeyName(10, "")
        Me.imgLstToolBtn.Images.SetKeyName(11, "")
        Me.imgLstToolBtn.Images.SetKeyName(12, "")
        Me.imgLstToolBtn.Images.SetKeyName(13, "")
        Me.imgLstToolBtn.Images.SetKeyName(14, "")
        Me.imgLstToolBtn.Images.SetKeyName(15, "")
        Me.imgLstToolBtn.Images.SetKeyName(16, "")
        Me.imgLstToolBtn.Images.SetKeyName(17, "")
        Me.imgLstToolBtn.Images.SetKeyName(18, "")
        Me.imgLstToolBtn.Images.SetKeyName(19, "")
        Me.imgLstToolBtn.Images.SetKeyName(20, "")
        Me.imgLstToolBtn.Images.SetKeyName(21, "")
        Me.imgLstToolBtn.Images.SetKeyName(22, "")
        Me.imgLstToolBtn.Images.SetKeyName(23, "")
        Me.imgLstToolBtn.Images.SetKeyName(24, "")
        Me.imgLstToolBtn.Images.SetKeyName(25, "")
        Me.imgLstToolBtn.Images.SetKeyName(26, "")
        Me.imgLstToolBtn.Images.SetKeyName(27, "")
        Me.imgLstToolBtn.Images.SetKeyName(28, "")
        Me.imgLstToolBtn.Images.SetKeyName(29, "")
        Me.imgLstToolBtn.Images.SetKeyName(30, "")
        Me.imgLstToolBtn.Images.SetKeyName(31, "")
        Me.imgLstToolBtn.Images.SetKeyName(32, "")
        Me.imgLstToolBtn.Images.SetKeyName(33, "")
        '
        'pnlLayouts
        '
        Me.pnlLayouts.BackColor = System.Drawing.SystemColors.Control
        Me.pnlLayouts.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle
        Me.pnlLayouts.Controls.Add(Me.lbLayouts)
        Me.pnlLayouts.Controls.Add(Me.cbLayouts)
        resources.ApplyResources(Me.pnlLayouts, "pnlLayouts")
        Me.pnlLayouts.Name = "pnlLayouts"
        '
        'lbLayouts
        '
        resources.ApplyResources(Me.lbLayouts, "lbLayouts")
        Me.lbLayouts.Name = "lbLayouts"
        '
        'cbLayouts
        '
        Me.cbLayouts.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList
        resources.ApplyResources(Me.cbLayouts, "cbLayouts")
        Me.cbLayouts.Name = "cbLayouts"
        Me.cbLayouts.Tag = "-1"
        '
        'trvPanel
        '
        resources.ApplyResources(Me.trvPanel, "trvPanel")
        Me.trvPanel.Controls.Add(Me.trvEntity)
        Me.trvPanel.Controls.Add(Me.spPropGrid)
        Me.trvPanel.Controls.Add(Me.propGrid)
        Me.trvPanel.Name = "trvPanel"
        '
        'trvEntity
        '
        Me.trvEntity.BackColor = System.Drawing.Color.Black
        Me.trvEntity.BorderStyle = System.Windows.Forms.BorderStyle.None
        Me.trvEntity.CheckBoxes = True
        resources.ApplyResources(Me.trvEntity, "trvEntity")
        Me.trvEntity.ForeColor = System.Drawing.Color.White
        Me.trvEntity.ItemHeight = 16
        Me.trvEntity.Name = "trvEntity"
        '
        'spPropGrid
        '
        resources.ApplyResources(Me.spPropGrid, "spPropGrid")
        Me.spPropGrid.Name = "spPropGrid"
        Me.spPropGrid.TabStop = False
        '
        'propGrid
        '
        resources.ApplyResources(Me.propGrid, "propGrid")
        Me.propGrid.LineColor = System.Drawing.SystemColors.ScrollBar
        Me.propGrid.Name = "propGrid"
        '
        'spTree
        '
        resources.ApplyResources(Me.spTree, "spTree")
        Me.spTree.Name = "spTree"
        Me.spTree.TabStop = False
        '
        'printPrevDlg
        '
        resources.ApplyResources(Me.printPrevDlg, "printPrevDlg")
        Me.printPrevDlg.Name = "printPrevDlg"
        '
        'dlgSaveDXF
        '
        Me.dlgSaveDXF.DefaultExt = "*.dxf"
        resources.ApplyResources(Me.dlgSaveDXF, "dlgSaveDXF")
        '
        'cadPictBox
        '
        Me.cadPictBox.BackColor = System.Drawing.Color.Black
        Me.cadPictBox.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle
        Me.cadPictBox.Cursor = System.Windows.Forms.Cursors.Default
        resources.ApplyResources(Me.cadPictBox, "cadPictBox")
        Me.cadPictBox.DoubleBuffering = True
        Me.cadPictBox.Name = "cadPictBox"
        Me.cadPictBox.Position = New System.Drawing.Point(0, 0)
        Me.cadPictBox.TabStop = False
        Me.cadPictBox.VirtualSize = New System.Drawing.Size(0, 0)
        '
        'dlgOpenSerializeFile
        '
        resources.ApplyResources(Me.dlgOpenSerializeFile, "dlgOpenSerializeFile")
        '
        'dlgSaveSerializeFile
        '
        resources.ApplyResources(Me.dlgSaveSerializeFile, "dlgSaveSerializeFile")
        '
        'dlgOpenFile
        '
        Me.dlgOpenFile.DefaultExt = "*.dxf;*.dwg"
        resources.ApplyResources(Me.dlgOpenFile, "dlgOpenFile")
        Me.dlgOpenFile.ShowHelp = True
        '
        'MainForm
        '
        resources.ApplyResources(Me, "$this")
        Me.BackColor = System.Drawing.SystemColors.Control
        Me.Controls.Add(Me.cadPictBox)
        Me.Controls.Add(Me.spTree)
        Me.Controls.Add(Me.stBar)
        Me.Controls.Add(Me.trvPanel)
        Me.Controls.Add(Me.pnlLayouts)
        Me.Controls.Add(Me.tlbTool)
        Me.Menu = Me.mainMenu
        Me.Name = "MainForm"
        Me.WindowState = System.Windows.Forms.FormWindowState.Maximized
        CType(Me.sbOpen, System.ComponentModel.ISupportInitialize).EndInit()
        CType(Me.sbScale, System.ComponentModel.ISupportInitialize).EndInit()
        CType(Me.sbCoord, System.ComponentModel.ISupportInitialize).EndInit()
        Me.pnlLayouts.ResumeLayout(False)
        Me.trvPanel.ResumeLayout(False)
        CType(Me.cadPictBox, System.ComponentModel.ISupportInitialize).EndInit()
        Me.ResumeLayout(False)
        Me.PerformLayout()

    End Sub
#End Region

    Private Sub InitLng()
        Me.mlng = New MultipleLanguage(MyBase.GetType)
        If (Not Me.mainMenu Is Nothing) Then
            Me.mlng.SaveNameMenuItem(Me.mainMenu.MenuItems)
        End If
        If (Not Me.ContextMenu Is Nothing) Then
            Me.mlng.SaveNameMenuItem(Me.ContextMenu.MenuItems)
        End If
        Me.mlng.SaveNameNoNameElement(MyBase.Controls)
    End Sub


    Private Sub InitialNewPrintPages()
        Me.prtForm.Image = Me.cadImageFld
        Me.prtForm.CreateNewPages()
    End Sub

    Private Sub InitParams()
        Me.showLineWeight = False
        Me.useSelectEntity = False
        Me.useSHXFonts = False
        Me.ChangeTypeFont()
        Me.textVisible = True
        Me.dimVisible = True
        Me.useWinEllipse = False
        Me.ImagePreviousScale = 1.0!
        Me.lngFile = ApplicationConstants.defaultstr
        Me.curLngIndex = 0
        Me.ImageScale = 1.0!
        Me.drawMode = True
        Me.PreviousPosition = New PointF
        Me.orb3D = New Orbit3D
        AddHandler Me.orb3D.RotateEvent, New CADImportEventHandler(AddressOf Me.ResizeLayout)
        Me.lForm = New LayerForm
        Me.aboutFrm = New AboutForm
        Me.shxFrm = New SHXForm
        Me.rasterSizeForm = New SetRasterSizeForm
        Me.openFromWebForm = New OpenFileFromWebForm
        Me.floatLicFrm = New FloatLicForm
        AddHandler Me.floatLicFrm.Change, New System.EventHandler(AddressOf Me.InvalidateImage)
        Me.regFrm = New RegForm
        Me.optForm = New OptionsForm
        Me.prtForm = New PrintingForm
        Me.prtForm.LayerForm = Me.lForm
        Me.listItemSelectDel = New ListItemSelectEventHandler(AddressOf Me.ListSelect)
        Me.useDoubleBuffering = True
    End Sub

    Private Sub InitSettings()
        Me.svSet = New SaveSettings(MainForm.fileSettingsName)
        Me.settingsLst = Me.svSet.LoadOptions
        If (Not Me.settingsLst Is Nothing) Then
            Dim key As String = ApplicationConstants.languagepath
            If Me.settingsLst.ContainsKey(key) Then
                Me.mlng.Path = Convert.ToString(Me.settingsLst.Item(key))
            End If
        Else
            Me.mlng.Path = CADConst.lngPathDefault
        End If
        Me.mlng.LoadLngFileList(Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0), New System.EventHandler(AddressOf Me.LanguageSelect_Click))
        If (Me.settingsLst Is Nothing) Then
            Me.CreateNewSettingsList()
        Else
            Me.SetSettings()
        End If
    End Sub

    Private Sub InvalidateImage(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub LanguageSelect_Click(ByVal sender As Object, ByVal e As EventArgs)
        If TypeOf sender Is MenuItem Then
            Dim mn As MenuItem = CType(sender, MenuItem)
            Me.curLngIndex = CByte(mn.Index)
            Me.lngFile = (mn.Text & ApplicationConstants.lngextstr)
            Me.SetAllFormsLanguageSettings()
            Me.SetLNG()
            Me.ChangeControlState()
        End If
    End Sub

    Private Sub ListSelect(ByVal item As ArrayList, ByVal e As ListEventSelectArgs)
        Dim itm1 As ListItem = Me.lForm.LayerList.Items.Item(e.ItemIndex)
        Dim index As Integer = Math.Floor(e.ItemIndex / Me.lForm.LayerList.Columns.Count)
        CADImportFace.SelectLayer(index, Me.cadImageFld)
        Select Case itm1.ImageIndex
            Case 3
                itm1.ImageIndex = 4
                Me.SetFreezeLayer(False, index)
                Exit Select
            Case 4
                itm1.ImageIndex = 3
                Me.SetFreezeLayer(True, index)
                Exit Select
            Case 7
                itm1.ImageIndex = 8
                Me.SetVisibleLayer(False, index)
                Exit Select
            Case 8
                itm1.ImageIndex = 7
                Me.SetVisibleLayer(True, index)
                Exit Select
        End Select
        If itm1.DrawColorRect Then
            Me.dlgSetColor.Color = itm1.BackColor
            If (Me.dlgSetColor.ShowDialog = System.Windows.Forms.DialogResult.OK) Then
                Me.SetColorLayer(Me.dlgSetColor.Color, index)
                itm1.BackColor = Me.dlgSetColor.Color
                Me.lForm.LayerList.InvalidateCell(e.ItemIndex)
            End If
        End If
        Me.lForm.LayerList.InvalidateCell(e.ItemIndex)
    End Sub

    ''' <summary>
    ''' Loads a CAD file.
    ''' </summary>
    Public Sub LoadFile(ByVal fileName As String)
        If (Not fileName Is Nothing) Then
            If (Not Me.cadImageFld Is Nothing) Then
                Me.cadImageFld.Dispose()
                Me.cadImageFld = Nothing
                Me.lForm.LayerList.Clear()
                RemoveHandler Me.lForm.LayerList.SelectItemEvent, Me.listItemSelectDel
            End If
            Me.Cursor = Cursors.WaitCursor
            Me.stBar.Panels.Item(0).Text = ApplicationConstants.loadfilestr
            Me.ImageScale = 1.0!
            Me.ImagePreviousScale = 1.0!
            Me.Position = New PointF
            Try
                Me.cadImageFld = CADImage.CreateImageByExtension(fileName)
            Catch ex As Exception
                MessageBox.Show(String.Format("[{0}] {1}", ex.Message, ex.StackTrace), ApplicationConstants.msgBoxDebugCaption, MessageBoxButtons.OK)
            End Try
            If TypeOf Me.cadImageFld Is CADRasterImage Then
                CType(Me.cadImageFld, CADRasterImage).Control = Me.cadPictBox
            End If
        End If
        If (Not Me.cadImageFld Is Nothing) Then
            Try
                If CADConst.IsWebPath(fileName) Then
                    Me.cadImageFld.LoadFromWeb(fileName)
                Else
                    Me.cadImageFld.LoadFromFile(fileName)
                End If
            Catch ex As Exception
                MessageBox.Show(String.Format("[{0}] {1}", ex.Message, ex.StackTrace), ApplicationConstants.msgBoxDebugCaption, MessageBoxButtons.OK)
            End Try
        End If
        Me.stBar.Panels.Item(0).Text = (Path.GetFileName(fileName) & ApplicationConstants.sepstr)
        cadImage.LastLoadedFilePath = Path.GetDirectoryName(fileName)
        Me.SetCADImageOptions()
    End Sub

    Private Shared Sub LoadParams(ByVal args As String())
        If (args.Length <> 0) Then
            MainForm.openFileName = args(0)
        End If
    End Sub

    <STAThread()> _
    Private Shared Sub Main(ByVal args As String())
        Application.EnableVisualStyles()
        Application.DoEvents()
        MainForm.LoadParams(args)
        Application.Run(New MainForm)
    End Sub

    Private Sub MainForm_Closing(ByVal sender As System.Object, ByVal e As System.ComponentModel.CancelEventArgs) Handles MyBase.Closing
        Me.CreateNewSettingsList()
        Me.svSet.SaveOptions(Me.settingsLst)
        If (Protection.LicenseType = LicenseType.Floating) Then
            Me.floatLicFrm.DisableFloating()
        Else
            Protection.CloseApplication()
        End If
    End Sub

    Private Sub MainForm_Deactivate(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Deactivate
        Me.detRMouseDown = False
    End Sub

    Private Sub MainForm_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        Me.VisibleAreaSize = New SizeF(Me.cadPictBox.Size.Width, Me.cadPictBox.Size.Height)
        If (Protection.LicenseType = LicenseType.Floating) Then
            Me.floatLicFrm.FloatingLicRegister()
        Else
            Protection.Register(Me)
        End If
        If (MainForm.openFileName <> String.Empty) Then
            Me.LoadFile(MainForm.openFileName)
        End If
        Me.ChangeControlState()
    End Sub

    Private Sub miAbout_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miAbout.Click
        Me.aboutFrm.ShowDialog()
    End Sub

    Private Sub miArcsSplit_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miArcsSplit.Click
        Me.SetUseWinEllipse()
        Me.ChangeControlState()
    End Sub

    Private Sub miBackView_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miBackView.Click, miBackOrbitView.Click
        Me.cadImageFld.RotToView(CADViewDirection.Back)
        Me.orb3D.OnRotate()
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub miBlackBackground_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miBlackBackground.Click
        Me.Black_Click()
        Me.ChangeControlState()
    End Sub

    Private Sub miBottomView_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miBottomView.Click
        Me.cadImageFld.RotToView(CADViewDirection.Bottom)
        Me.orb3D.OnRotate()
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub miChangeBackgroundColor_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miChangeBackgroundColor.Click
        Me.Color_Click()
        Me.ChangeControlState()
    End Sub

    Private Sub miClosePicture_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miClosePicture.Click
        Me.CloseFile()
        Me.ChangeControlState()
    End Sub

    Private Sub miCopyAsBMP_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miCopyAsBMP.Click
        Me.PutToClipboard()
    End Sub

    Private Sub miCustomPrint_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miCustomPrint.Click
        Me.prtForm.ShowDialog()
    End Sub

    Private Sub miDimShow_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miDimShow.Click
        Me.ChangeDimensionsVisiblity()
        Me.ChangeControlState()
    End Sub

    Private Sub miDrawBlackColor_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miDrawBlackColor.Click
        Me.DoBlackColor()
        Me.ChangeControlState()
    End Sub

    Private Sub miDrawNormalColor_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miDrawNormalColor.Click
        Me.DoNormalColor()
        Me.ChangeControlState()
    End Sub

    Private Sub miEnable3DOrbit_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miEnable3DOrbit.Click
        Me.Go3dOrbit(Not Me.orb3D.Visible)
        Me.ChangeControlState()
    End Sub

    Private Sub miExit_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miExit.Click
        MyBase.Close()
    End Sub

    Private Sub miFitToWindow_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miFitToWindow.Click
        Me.ResetScaling()
    End Sub

    Private Sub miFloatLic_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miFloatLic.Click
        Me.floatLicFrm.ShowDialog()
    End Sub

    Private Sub miFrontView_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miFrontView.Click, miFrontOrbitView.Click
        Me.cadImageFld.RotToView(CADViewDirection.Front)
        Me.orb3D.OnRotate()
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub miInitialView_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miInitialView.Click, miInitialOrbitView.Click
        Me.cadImageFld.RotDefault()
        Me.orb3D.OnRotate()
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub miLayersShow_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miLayersShow.Click
        Me.SetLayList()
        Me.lForm.ShowDialog()
    End Sub

    Private Sub miLeftView_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miLeftView.Click, miLeftOrbitView.Click
        Me.cadImageFld.RotToView(CADViewDirection.Left)
        Me.orb3D.OnRotate()
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub miNEIsometricView_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miNEIsometricView.Click, miNEOrbitView.Click
        Me.cadImageFld.RotToView(CADViewDirection.NEIsometric)
        Me.orb3D.OnRotate()
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub miNWIsometricView_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miNWIsometricView.Click, miNWOrbitView.Click
        Me.cadImageFld.RotToView(CADViewDirection.NWIsometric)
        Me.orb3D.OnRotate()
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub miOpenFile_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miOpenFile.Click
        Me.ShowLoadFileDialog()
        Me.ChangeControlState()
    End Sub

    Private Sub miOpenFromWeb_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miOpenFromWeb.Click
        If (Me.openFromWebForm.ShowDialog = System.Windows.Forms.DialogResult.OK) Then
            Me.LoadFile(Me.openFromWebForm.Path)
            Me.ChangeControlState()
        End If
    End Sub

    Private Sub miPrint_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miPrint.Click
        Me.cadImageFld.Print(True, True, Nothing)
    End Sub

    Private Sub miPrintPreview_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miPrintPreview.Click
        Me.prtForm.TypePage = DrawingSize.Fit
        Me.printPrevDlg.Document = Me.prtForm.Print(False)
        Me.printPrevDlg.ShowDialog()
        If (Not Me.printPrevDlg.Document Is Nothing) Then
            Me.printPrevDlg.Document.Dispose()
        End If
    End Sub

    Private Sub miRegistration_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miRegistration.Click
        Me.regFrm.ShowDialog()
    End Sub

    Private Sub miRightView_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miRightView.Click, miRightOrbitView.Click
        Me.cadImageFld.RotToView(CADViewDirection.Right)
        Me.orb3D.OnRotate()
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub miSaveAsDXF_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miSaveAsDXF.Click
        If (Not Me.cadImageFld Is Nothing) Then
            If (Not Me.cadImageFld.FileInf Is Nothing) Then
                Me.dlgSaveDXF.FileName = Me.cadImageFld.FileInf.Name.Replace(Me.cadImageFld.FileInf.Extension, String.Empty)
            End If
            If (Me.dlgSaveDXF.ShowDialog = System.Windows.Forms.DialogResult.OK) Then
                Me.SaveAsDXF(Me.dlgSaveDXF.FileName)
            End If
        End If
    End Sub

    Private Sub miSaveFile_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miSaveFile.Click
        Me.SaveAsImage()
    End Sub

    Private Sub miSEIsometricView_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miSEIsometricView.Click, miSEOrbitView.Click
        Me.cadImageFld.RotToView(CADViewDirection.SEIsometric)
        Me.orb3D.OnRotate()
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub miShowEntityTree_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miShowEntityTree.Click
        Me.ChangeTreeVisiblity(Not Me.trvEntity.Visible)
        Me.ChangeControlState()
    End Sub

    Private Sub miShowLineWeight_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miShowLineWeight.Click
        Me.ChangeShowLineWeight()
        Me.ChangeControlState()
    End Sub

    Private Sub miShowOptionsForm_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miShowOptionsForm.Click
        Me.CreateNewSettingsList()
        If (Me.optForm.ShowDialog <> System.Windows.Forms.DialogResult.Cancel) Then
        End If
    End Sub

    Private Sub miShowShxForm_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miShowShxForm.Click
        Me.AddSHXPaths()
        Me.ChangeControlState()
    End Sub

    Private Sub miSWIsometricView_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miSWIsometricView.Click, miSWOrbitView.Click
        Me.cadImageFld.RotToView(CADViewDirection.SWIsometric)
        Me.orb3D.OnRotate()
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub miTextsShow_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miTextsShow.Click
        Me.ChangeTextsVisiblity()
        Me.ChangeControlState()
    End Sub

    Private Sub miTopView_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miTopView.Click, miTopOrbitView.Click, miBottomOrbitView.Click
        Me.cadImageFld.RotToView(CADViewDirection.Top)
        Me.orb3D.OnRotate()
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub miWhiteBackground_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miWhiteBackground.Click
        Me.White_Click()
        Me.ChangeControlState()
    End Sub

    Private Sub miZoom_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miZoom10.Click, miZoom25.Click, miZoom50.Click, miZoom100.Click, miZoom200.Click, miZoom400.Click, miZoom800.Click
        If (Not Me.cadImageFld Is Nothing) Then
            Dim i As Single = Me.ImageScale
            Select Case CType(sender, MenuItem).Index
                Case 0
                    i = 0.1!
                    Exit Select
                Case 1
                    i = 0.25!
                    Exit Select
                Case 2
                    i = 0.5!
                    Exit Select
                Case 3
                    i = 1.0!
                    Exit Select
                Case 4
                    i = 2.0!
                    Exit Select
                Case 5
                    i = 4.0!
                    Exit Select
                Case 6
                    i = 8.0!
                    Exit Select
            End Select
            Me.ResetScaling()
            Me.PreviousPosition = New PointF((CSng(Me.cadPictBox.ClientRectangle.Width) / 2.0!), (CSng(Me.cadPictBox.ClientRectangle.Height) / 2.0!))
            Me.ImageScale = i
            Me.cadPictBox.Invalidate()            
        End If
    End Sub

    Private Sub miZoomIn_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miZoomIn.Click
        Me.DoZoomIn()
    End Sub

    Private Sub miZoomOut_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles miZoomOut.Click
        Me.DoZoomOut()
    End Sub

    Private Function MultipleSelect() As Boolean
        If (Me.cadImageFld.SelectionMode = SelectionEntityMode.Enabled) Then
            Dim l As Integer = Me.clipRectangle.ClientRectangle.Left
            Dim t As Integer = Me.clipRectangle.ClientRectangle.Top
            Dim pt1 As DPoint = Me.GetRealPoint(l, t)
            Dim pt2 As DPoint = Me.GetRealPoint(Me.clipRectangle.ClientRectangle.Right, Me.clipRectangle.ClientRectangle.Bottom)
            Dim tmpRect As New DRect(pt1.X, pt1.Y, pt2.X, pt2.Y)
            Dim rg As Region = Me.cadImageFld.GetSelectEntityRegion(New Rectangle(l, t, Me.clipRectangle.ClientRectangle.Width, Me.clipRectangle.ClientRectangle.Height))
            Me.cadImageFld.MultipleSelect(tmpRect, True, True)
            Me.cadPictBox.Invalidate(rg)
            rg.Dispose()
            Return True
        End If
        Return False
    End Function

    Private Sub NotSupportedInCurrentVersion()
        Me.Cursor = Cursors.Default
        Me.cadPictBox.Visible = True
        Me.stBar.Panels.Item(0).Text = ApplicationConstants.notsupportedstr
        MessageBox.Show(ApplicationConstants.notsupportedextstr, ApplicationConstants.appnamestr)
    End Sub

    Private Sub propGrid_PropertyValueChanged(ByVal s As System.Object, ByVal e As System.Windows.Forms.PropertyValueChangedEventArgs) Handles propGrid.PropertyValueChanged
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub PutToClipboard()
        If Me.clipRectangle.Enabled Then
            Dim tmpRect As DRect = Me.ImageDRect
            Me.cadImageFld.SaveImageToClipboard(tmpRect, Me.clipRectangle.ClientRectangle)
        Else
            Dim tmp As New DRect(0, 0, CDbl((Me.VisibleAreaSize.Width * Me.ImageScale)), CDbl((Me.VisibleAreaSize.Height * Me.ImageScale)))
            Me.cadImageFld.SaveImageToClipboard(tmp)
        End If
    End Sub

    Friend Sub ReloadLNG()
        Me.mlng.LoadLngFileList(Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0), New System.EventHandler(AddressOf Me.LanguageSelect_Click))
    End Sub

    Friend Sub ReloadLNG(ByVal val As String)
        Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Clear()
        Me.mlng.Path = val
        Me.mlng.LoadLngFileList(Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0), New System.EventHandler(AddressOf Me.LanguageSelect_Click))
        If (Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Count > Me.curLngIndex) Then
            Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Item(Me.curLngIndex).Checked = True
        End If
    End Sub

    ''' <summary>
    ''' Reopens a file after selecting or deselecting SHX fonts. 
    ''' </summary>
    ''' <remarks>This method is also called when the paths to the files containing 
    ''' SHX fonts have been edited in the <b>SHX Paths</b> window invoked by the <b>SHX Fonts</b> menu item.
    ''' </remarks>
    Public Sub ReOpen()
        If ((Not Me.dlgOpenFile.FileName Is Nothing) AndAlso File.Exists(Me.dlgOpenFile.FileName)) Then
            Me.LoadFile(Me.dlgOpenFile.FileName)
        End If
    End Sub

    ''' <summary>
    ''' Sets the scale and position of the current CAD image to its original values.
    ''' </summary>
    Public Sub ResetScaling()
        Me.ImageScale = 1.0!
        Me.ImagePreviousScale = 1.0!
        Me.LeftImagePosition = ((Me.cadPictBox.ClientRectangle.Width - Me.VisibleAreaSize.Width) / 2.0!)
        Me.TopImagePosition = ((Me.cadPictBox.ClientRectangle.Height - Me.VisibleAreaSize.Height) / 2.0!)
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub ResizeLayout()
        If (Not Me.cadImageFld Is Nothing) Then
            Me.cadImageFld.GetExtents()
            Me.DoResize()
        End If
    End Sub

    Private Sub Rotate2D(ByVal angle As Single)
        Me.cadImageFld.Rotate(Axes.Z, angle)
        Me.cadImageFld.GetExtents()
        Me.cadImageFld.ClearBuffer()
        Me.DoResize()
    End Sub

    Private Sub SaveAsDXF(ByVal fName As String)
        Dim exp1 As CADtoDXF
        If (Not Me.cadImageFld Is Nothing) Then
            If TypeOf Me.cadImageFld Is CADRasterImage Then
                If ((Not Me.cadImageFld.FileInf Is Nothing) AndAlso (Me.cadImageFld.FileInf.Extension.ToUpper = ApplicationConstants.emfextstr)) Then
                    Me.cadImageFld.EmfConvertToDXF(Me.cadImageFld.FileInf.FullName, Me.cadPictBox.Handle, fName)
                End If
            Else
                exp1 = New CADtoDXF(Me.cadImageFld)
                exp1.SaveToFile(fName)
            End If
        End If
    End Sub

    ''' <summary>
    ''' Invokes a <see cref="T:System.Windows.Forms.SaveFileDialog">SaveFileDialog</see> box where 
    ''' a user can select a directory and format for saving the current CAD image.
    ''' </summary>
    ''' <remarks><p>This method can be invoked from the toolbar and from the main menu.</p>
    ''' <p>Images can be saved in the following formats: JPG, BMP, TIFF, GIF, EMF.</p></remarks>
    Public Sub SaveAsImage()
        If (Not Me.cadImageFld Is Nothing) Then
            If (Not Me.cadImageFld.FileInf Is Nothing) Then
                Me.dlgSaveImg.FileName = Me.cadImageFld.FileInf.Name.Replace(Me.cadImageFld.FileInf.Extension, String.Empty)
            End If
            If (Me.dlgSaveImg.ShowDialog = System.Windows.Forms.DialogResult.OK) Then
                Dim tmpRect As New DRect(0, 0, CDbl((Me.VisibleAreaSize.Width * Me.ImageScale)), CDbl((Me.VisibleAreaSize.Height * Me.ImageScale)))
                Dim imgFrm As ImageFormat = ImageFormat.Bmp
                If (Not Me.dlgSaveImg.FileName Is Nothing) Then
                    Dim tmp As String = Me.dlgSaveImg.FileName
                    If (tmp.ToUpper.IndexOf(ApplicationConstants.jpgextstr) <> -1) Then
                        imgFrm = ImageFormat.Jpeg
                    End If
                    If (tmp.ToUpper.IndexOf(ApplicationConstants.bmpextstr) <> -1) Then
                        imgFrm = ImageFormat.Bmp
                    End If
                    If (tmp.ToUpper.IndexOf(ApplicationConstants.tiffextstr) <> -1) Then
                        imgFrm = ImageFormat.Tiff
                    End If
                    If (tmp.ToUpper.IndexOf(ApplicationConstants.gifextstr) <> -1) Then
                        imgFrm = ImageFormat.Gif
                    End If
                    If (tmp.ToUpper.IndexOf(ApplicationConstants.emfextstr) <> -1) Then
                        imgFrm = ImageFormat.Emf
                    End If
                    If (tmp.ToUpper.IndexOf(ApplicationConstants.wmfextstr) <> -1) Then
                        imgFrm = ImageFormat.Wmf
                    End If
                    If (tmp.ToUpper.IndexOf(ApplicationConstants.pngextstr) <> -1) Then
                        imgFrm = ImageFormat.Png
                    End If
                    If (tmp.ToUpper.IndexOf(ApplicationConstants.dxfextstr) <> -1) Then
                        Me.SaveAsDXF(Me.dlgSaveImg.FileName)
                        Return
                    End If
                End If
                If Not Me.clipRectangle.Enabled Then
                    Me.rasterSizeForm.Image = Me.cadImageFld
                    Me.rasterSizeForm.CurrentSize = tmpRect
                    Me.rasterSizeForm.SaveFileName = Me.dlgSaveImg.FileName
                    If (Me.rasterSizeForm.ShowDialog = System.Windows.Forms.DialogResult.OK) Then
                        tmpRect = Me.rasterSizeForm.SizeImage
                    End If
                End If
                Dim tmpNumberOfPartsInCircle As Integer = Me.cadImageFld.NumberOfPartsInCircle
                Me.cadImageFld.NumberOfPartsInCircle = CADConst.SetNumberOfPartsInCurve(tmpRect)
                If Me.clipRectangle.Enabled Then
                    If ((imgFrm Is ImageFormat.Emf) OrElse (imgFrm Is ImageFormat.Wmf)) Then
                        Me.cadImageFld.ExportToMetafile(Me.dlgSaveImg.FileName, tmpRect, Me.clipRectangle.ClientRectangle)
                    Else
                        Me.cadImageFld.SaveToFile(Me.dlgSaveImg.FileName, imgFrm, tmpRect, Me.clipRectangle.ClientRectangle, Me.rasterSizeForm.ImagePixelFormat)
                    End If
                ElseIf ((imgFrm Is ImageFormat.Emf) OrElse (imgFrm Is ImageFormat.Wmf)) Then
                    Me.cadImageFld.ExportToMetafile(Me.dlgSaveImg.FileName, tmpRect)
                Else
                    Me.cadImageFld.SaveToFile(Me.dlgSaveImg.FileName, imgFrm, tmpRect, Me.rasterSizeForm.ImagePixelFormat)
                End If
                Me.cadImageFld.NumberOfPartsInCircle = tmpNumberOfPartsInCircle
            End If
        End If
    End Sub

    Private Sub SetAllFormsLanguageSettings()
        Me.optForm.MultipleLanguagesPath = Me.mlng.Path
        Me.optForm.LngFileName = Me.lngFile
        Me.aboutFrm.MultipleLanguagesPath = Me.mlng.Path
        Me.aboutFrm.LngFileName = Me.lngFile
        Me.floatLicFrm.MultipleLanguagesPath = Me.mlng.Path
        Me.floatLicFrm.LngFileName = Me.lngFile
        Me.lForm.MultipleLanguagesPath = Me.mlng.Path
        Me.lForm.LngFileName = Me.lngFile
        Me.prtForm.MultipleLanguagesPath = Me.mlng.Path
        Me.prtForm.LngFileName = Me.lngFile
        Me.regFrm.MultipleLanguagesPath = Me.mlng.Path
        Me.regFrm.LngFileName = Me.lngFile
        Me.rasterSizeForm.MultipleLanguagesPath = Me.mlng.Path
        Me.rasterSizeForm.LngFileName = Me.lngFile
        Me.shxFrm.MultipleLanguagesPath = Me.mlng.Path
        Me.shxFrm.LngFileName = Me.lngFile
    End Sub

    Private Sub SetAllFormsSettings()
        Me.SetAllFormsLanguageSettings()
        Me.optForm.SettingsList = Me.settingsLst
        AddHandler Me.optForm.ChangeLngPath, New ChangeLngPathEventHandler(AddressOf Me.ReloadLNG)
        AddHandler Me.optForm.ChangeLanguage, New ChangeLanguageEventHandler(AddressOf Me.ChangeLanguage)
        AddHandler Me.optForm.ChangeEntityPanelVisible, New ChangeOptionsEventHandler(AddressOf Me.ChangeTreeVisible)
        AddHandler Me.optForm.ChangeBackgroundColor, New ChangeOptionsEventHandler(AddressOf Me.ChangeBackColor)
        AddHandler Me.optForm.ChangeDrawingColors, New ChangeOptionsEventHandler(AddressOf Me.ChangeDrawingColors)
    End Sub

    Public Sub SetCADImageOptions()
        Me.cadImageFld.UseWinEllipse = False
        Me.cadImageFld.IsShowLineWeight = False
        Me.cadImageFld.IsShowLineWeight = Me.showLineWeight
        Me.showLineWeight = False
        Me.cadImageFld.UseDoubleBuffering = Me.useDoubleBuffering
        Me.useSelectEntity = False
        Me.orb3D.CADImage = Me.cadImageFld
        Me.orb3D.Visible = False
        Me.orb3D.Disable3dOrbit()
        If (Me.cadPictBox.BackColor.Equals(Color.White)) Then
            Me.White_Click()
        Else
            Me.Black_Click()
        End If
        Me.ViewLayouts()
        Me.cadImageFld.IsDraw3DAxes = Me.tlbAxes.Pushed
        Me.Cursor = Cursors.Default
        If Me.trvPanel.Visible Then
            CADImportFace.LoadTreeNodes(Me.trvEntity.Nodes, Me.cadImageFld)
        End If
        If Not Me.drawMode Then
            Me.DoBlackColor()
        End If
        Me.SetLayList()
        ObjEntity.cadImage = Me.cadImageFld
        Me.prtForm.Image = Me.cadImageFld
        ObjEntity.propGrid = Me.propGrid
        Me.DoResize()        
    End Sub

    Public Sub SetColorLayer(ByVal color As Color, ByVal index As Integer)
        Me.cadImageFld.SetLayerColor(index, color, Me.lForm.detInvalidate)
        Me.InitialNewPrintPages()
        Me.cadPictBox.Invalidate()
    End Sub

    Public Sub SetFreezeLayer(ByVal visible As Boolean, ByVal index As Integer)
        Me.cadImageFld.SetLayerFreeze(index, visible, Me.lForm.detInvalidate)
        Me.InitialNewPrintPages()
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub SetLayList()
        If ((Me.lForm.LayerList.Items.Count = 0) AndAlso (Not Me.cadImageFld Is Nothing)) Then
            ObjEntity.LayersList = New String(Me.cadImageFld.LayersCount - 1) {}
            Me.lForm.LayerList.Columns.Add(New ListHeader(ApplicationConstants.headstr1, ApplicationConstants.namestr, 0))
            Me.lForm.LayerList.Columns.Add(New ListHeader(ApplicationConstants.headstr2, ApplicationConstants.visiblestr, 0))
            Me.lForm.LayerList.Columns.Add(New ListHeader(ApplicationConstants.headstr4, ApplicationConstants.freezestr, 0))
            Me.lForm.LayerList.Columns.Add(New ListHeader(ApplicationConstants.headstr3, ApplicationConstants.colorstr, 0))
            Dim I As Integer
            For I = 0 To Me.cadImageFld.LayersCount - 1
                Dim tmp As String = Me.cadImageFld.GetLayerName(I)
                Dim colorLay As Color = Me.cadImageFld.GetLayerColor(I)
                ObjEntity.LayersList(I) = tmp
                Me.AddRecordToLayerList(tmp, colorLay, Me.cadImageFld.GetLayerVisible(I), Me.cadImageFld.GetLayerFreeze(I))
            Next I
            Me.lForm.LayerList.SetAutoSize()
            AddHandler Me.lForm.LayerList.SelectItemEvent, Me.listItemSelectDel
        End If
    End Sub

    Private Sub SetLNG()
        Me.mlng.LoadLNG(Me.lngFile)
        Me.mlng.RestoreLanguage(MyBase.Controls, MyBase.Menu)
        Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Clear()
        Me.mlng.LoadLngFileList(Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0), New System.EventHandler(AddressOf Me.LanguageSelect_Click))
        Me.Text = ApplicationConstants.appnamestr
        Me.Text = Me.mlng.SetLanguage(MyBase.Controls, MyBase.Menu, Me.Text)
    End Sub

    Public Sub SetSizePictureBox(ByVal sz As Size)
        If ((((Me.pos.X < 0.0!) OrElse (Me.pos.Y < 0.0!)) OrElse (((Me.pos.X + sz.Width) > Me.cadPictBox.Width) OrElse ((Me.pos.Y + sz.Height) > Me.cadPictBox.Height))) AndAlso Me.SizeEqualSizeImageAndPictBox) Then
            If (Me.pos.X < 0.0!) Then
                sz.Width = (Me.cadPictBox.Width - CInt(Me.pos.X))
            End If
            If (Me.pos.Y < 0.0!) Then
                sz.Height = (Me.cadPictBox.Height - CInt(Me.pos.Y))
            End If
            If ((Me.pos.X + sz.Width) > Me.cadPictBox.Width) Then
                sz.Width = (Me.cadPictBox.Width + CInt(Me.pos.X))
            End If
            If ((Me.pos.Y + sz.Height) > Me.cadPictBox.Height) Then
                sz.Height = (Me.cadPictBox.Height + CInt(Me.pos.Y))
            End If
        End If
        Me.cadPictBox.SetVirtualSizeNoInvalidate(sz)
    End Sub

    Private Function SizeEqualSizeImageAndPictBox() As Boolean
        Dim tmp As RectangleF = Me.ImageRectangleF
        Return ((tmp.Width <= Me.cadPictBox.Size.Width) OrElse (tmp.Height <= Me.cadPictBox.Height))
    End Function

    Private Sub SetPictureBoxPosition(ByVal value As PointF)
        Dim w1 As Integer
        Dim h1 As Integer
        If (value.X > 0.0!) Then
            w1 = 0
        Else
            w1 = CInt(Math.Abs(value.X))
        End If
        If (w1 > Me.cadPictBox.VirtualSize.Width) Then
            w1 = Me.cadPictBox.VirtualSize.Width
        End If
        If (value.Y > 0.0!) Then
            h1 = 0
        Else
            h1 = CInt(Math.Abs(value.Y))
        End If
        If (h1 > Me.cadPictBox.VirtualSize.Height) Then
            h1 = Me.cadPictBox.VirtualSize.Height
        End If
        Me.cadPictBox.SetPositionNoInvalidate(New Point(w1, h1))
    End Sub

    Friend Sub SetSettings()
        If (Not Me.settingsLst Is Nothing) Then
            Dim cn As Integer = 0
            Dim key As String = ApplicationConstants.languagepath
            If Me.settingsLst.ContainsKey(key) Then
                Me.mlng.Path = Convert.ToString(Me.settingsLst.Item(key))
            End If
            key = ApplicationConstants.languagestr
            If Me.settingsLst.ContainsKey(key) Then
                Me.lngFile = CStr(Me.settingsLst.Item(key))
            End If
            Me.mlng.LoadLNG(Me.lngFile)
            Me.Text = Me.mlng.SetLanguage(MyBase.Controls, MyBase.Menu, Me.Text)
            key = ApplicationConstants.languageIDstr
            If Me.settingsLst.ContainsKey(key) Then
                Me.curLngIndex = Convert.ToByte(Me.settingsLst.Item(key))
            End If
            key = ApplicationConstants.backcolorstr
            Dim tmp As String = ApplicationConstants.blackstr
            If Me.settingsLst.ContainsKey(key) Then
                tmp = Convert.ToString(Me.settingsLst.Item(key))
            End If
            If (tmp.ToUpper = ApplicationConstants.blackstr) Then
                Me.Black_Click()
            Else
                Me.White_Click()
            End If
            key = ApplicationConstants.showentitystr
            If Me.settingsLst.ContainsKey(key) Then
                tmp = Convert.ToString(Me.settingsLst.Item(key))
            End If
            If (tmp.ToUpper = ApplicationConstants.truestr) Then
                Me.trvPanel.Visible = True
            Else
                Me.trvPanel.Visible = False
            End If
            key = ApplicationConstants.drawmodestr
            If Me.settingsLst.ContainsKey(key) Then
                tmp = Convert.ToString(Me.settingsLst.Item(key))
            End If
            If (tmp.ToUpper = ApplicationConstants.truestr) Then
                Me.drawMode = True
            Else
                Me.drawMode = False
            End If
            key = ApplicationConstants.shxpathcnstr
            If Me.settingsLst.ContainsKey(key) Then
                cn = Convert.ToInt32(Me.settingsLst.Item(key))
            End If
            Dim i As Integer
            For i = 0 To cn - 1
                key = String.Format("SHXPath_{0}", (i + 1))
                If Me.settingsLst.ContainsKey(key) Then
                    Me.shxFrm.AddPath(Convert.ToString(Me.settingsLst.Item(key)))
                End If
            Next i
            key = ApplicationConstants.installstr
            If (Me.settingsLst.ContainsKey(key) AndAlso CADConst.SearchSHXPaths) Then
                Me.shxFrm.lstDir.Items.Clear()
                Me.shxFrm.lstPath.Clear()
                Dim vPaths As New ArrayList
                CADConst.FindAutoCADSHXPaths(vPaths)
                For i = 0 To vPaths.Count - 1
                    tmp = CStr(vPaths.Item(i))
                    Me.shxFrm.lstDir.Items.Add(tmp)
                    Me.shxFrm.lstPath.Add(tmp, String.Empty)
                    CADConst.SHXSearchPaths = (CADConst.SHXSearchPaths & CADConst.SHXSearchPaths & tmp & ApplicationConstants.sepstr3)
                Next i
            End If
            key = ApplicationConstants.typelcstr
            If Me.settingsLst.ContainsKey(key) Then
                tmp = CStr(Me.settingsLst.Item(key))
                If (tmp = ApplicationConstants.floatingstr) Then
                    Protection.LicenseType = LicenseType.Floating
                    key = ApplicationConstants.hoststr
                    If Me.settingsLst.ContainsKey(key) Then
                        Me.floatLicFrm.Host = CStr(Me.settingsLst.Item(key))
                    End If
                    key = ApplicationConstants.portstr
                    If Me.settingsLst.ContainsKey(key) Then
                        Me.floatLicFrm.Port = Convert.ToInt32(Me.settingsLst.Item(key))
                    End If
                    key = ApplicationConstants.appconst
                    If Me.settingsLst.ContainsKey(key) Then
                        Me.floatLicFrm.App = CStr(Me.settingsLst.Item(key))
                    End If
                Else
                    Protection.LicenseType = LicenseType.Register
                End If
            End If
        End If
    End Sub

    Public Sub SetVisibleLayer(ByVal visible As Boolean, ByVal index As Integer)
        Me.cadImageFld.SetLayerVisible(index, visible, Me.lForm.detInvalidate)
        Me.InitialNewPrintPages()
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub Shift()
        Me.LeftImagePosition = (Me.PreviousPosition.X - (((Me.PreviousPosition.X - Me.LeftImagePosition) * Me.ImageScale) / Me.ImagePreviousScale))
        Me.TopImagePosition = (Me.PreviousPosition.Y - (((Me.PreviousPosition.Y - Me.TopImagePosition) * Me.ImageScale) / Me.ImagePreviousScale))
        Me.ImagePreviousScale = Me.ImageScale
    End Sub

    Public Sub ShowLoadFileDialog()
        Me.DeactCADImage()
        Me.cadPictBox.Enabled = False
        If (Me.dlgOpenFile.ShowDialog <> System.Windows.Forms.DialogResult.OK) Then
            Me.cadPictBox.Visible = True
            Me.cadPictBox.Enabled = True
        Else
            Me.cadPictBox.Enabled = True
            Me.LoadFile(Me.dlgOpenFile.FileName)
        End If
    End Sub

    Private Sub spTree_SplitterMoved(ByVal sender As System.Object, ByVal e As System.Windows.Forms.SplitterEventArgs) Handles spTree.SplitterMoved
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub tlbTool_ButtonClick(ByVal sender As System.Object, ByVal e As System.Windows.Forms.ToolBarButtonClickEventArgs) Handles tlbTool.ButtonClick
        If ((Not Me.cadImageFld Is Nothing) OrElse (Me.tlbTool.Buttons.IndexOf(e.Button) <> 8)) Then
            Select Case Me.tlbTool.Buttons.IndexOf(e.Button)
                Case 0
                    Me.ShowLoadFileDialog()
                    Exit Select
                Case 1
                    Me.DoZoomIn()
                    Exit Select
                Case 2
                    Me.DoZoomOut()
                    Exit Select
                Case 3
                    Me.SaveAsImage()
                    Exit Select
                Case 4
                    Me.White_Click()
                    Exit Select
                Case 5
                    Me.Black_Click()
                    Exit Select
                Case 6
                    Me.Color_Click()
                    Exit Select
                Case 7
                    Me.Go3dOrbit(Not Me.orb3D.Visible)
                    Exit Select
                Case 8
                    Me.Rotate2D(90.0!)
                    Exit Select
                Case 9
                    Me.Rotate2D(-90.0!)
                    Exit Select
                Case 10
                    Me.Rotate2D(10.0!)
                    Exit Select
                Case 11
                    Me.SetLayList()
                    Me.lForm.ShowDialog()
                    Exit Select
                Case 12
                    Me.SetUseWinEllipse()
                    Exit Select
                Case 13
                    Me.DoBlackColor()
                    Exit Select
                Case 14
                    Me.DoNormalColor()
                    Exit Select
                Case 15
                    Me.ResetScaling()
                    Exit Select
                Case &H10
                    Me.ChangeTextsVisiblity()
                    Exit Select
                Case &H11
                    Me.ChangeDimensionsVisiblity()
                    Exit Select
                Case &H12
                    Me.PutToClipboard()
                    Exit Select
                Case &H13
                    Me.cadImageFld.Print(True, True, Nothing)
                    Exit Select
                Case 20
                    Me.ChangeTypeFont()
                    Exit Select
                Case &H15
                    Me.DoEnableRectangle(Not Me.clipRectangle.Enabled)
                    Exit Select
                Case &H16
                    Me.useSelectEntity = Not Me.useSelectEntity
                    Me.ChangeSelectionCond(True)
                    Exit Select
                Case &H17
                    Me.cadImageFld.IsDraw3DAxes = Not Me.cadImageFld.IsDraw3DAxes
                    Me.cadPictBox.Invalidate()
                    Exit Select
                Case &H18
                    Me.GetFromClipboard()
                    Exit Select
                Case &H19
                    Me.useDoubleBuffering = Not Me.useDoubleBuffering
                    Me.ChangeDoubleBufferingMode()
                    Exit Select
            End Select
            Me.ChangeControlState()
        End If
    End Sub

    Private Sub trvEntity_AfterCheck(ByVal sender As System.Object, ByVal e As System.Windows.Forms.TreeViewEventArgs) Handles trvEntity.AfterCheck
        CADImportFace.DoCheckTreeNode(Me.trvEntity.Nodes, e.Node, Me.cadImageFld, Me.cadPictBox)
    End Sub

    Private Sub trvEntity_AfterSelect(ByVal sender As System.Object, ByVal e As System.Windows.Forms.TreeViewEventArgs) Handles trvEntity.AfterSelect
        CADImportFace.DecodeEntity(e.Node, Me.cadImageFld, Me.cadPictBox, Me.ImageScale)
    End Sub

    ''' <summary>
    ''' Alternately changes a boolean value indicating whether arcs and circles in the CAD image 
    ''' are drawn with GDI+ drawing methods without linearization. 
    ''' </summary>	
    Public Sub SetUseWinEllipse()
        Me.useWinEllipse = Not Me.useWinEllipse
        cadImageFld.UseWinEllipse = Me.useWinEllipse
        cadPictBox.Invalidate()
    End Sub


    ''' <summary>
    ''' Creates a list of layouts of the CAD image and sets a current layout. 
    ''' </summary>
    Public Sub ViewLayouts()
        If (Not Me.cadImageFld Is Nothing) Then
            Me.cbLayouts.Items.Clear()
            Dim i As Integer
            For i = 0 To Me.cadImageFld.LayoutsCount - 1
                Me.cbLayouts.Items.Add(Me.cadImageFld.GetLayoutName(i))
            Next i
            If (Me.cbLayouts.Items.Count > Me.cadImageFld.DefaultLayoutIndex) Then
                Me.cbLayouts.SelectedIndex = Me.cadImageFld.DefaultLayoutIndex
                If (Me.cbLayouts.SelectedIndex >= 0) Then
                    Me.cadImageFld.SetCurrentLayout(Me.cbLayouts.SelectedIndex)
                End If
            End If
        End If
    End Sub

    ''' <summary>
    ''' Paints the CAD image background in the white color.
    ''' </summary>
    Public Sub White_Click()
        Me.cadPictBox.BackColor = Color.White
        Me.trvEntity.BackColor = Color.White
        Me.trvEntity.ForeColor = Color.Black
        If (Not Me.cadImageFld Is Nothing) Then
            Me.cadImageFld.DefaultColor = Color.Black
            Me.cadImageFld.BackgroundColor = Color.White
        End If
        If (Not Me.clipRectangle Is Nothing) Then
            Me.clipRectangle.Color = Color.Black
        End If
    End Sub

    ''' <summary>
    ''' Adjusts the image size according to the specified scale.
    ''' </summary>
    ''' <param name="i">A scale value.</param>
    ''' <remarks>If the scale value is more than one the image size increases; otherwise, decreases.</remarks>
    Public Sub Zoom(ByVal i As Single)
        If (Not Me.cadImageFld Is Nothing) Then
            Me.ImageScale = (Me.ImageScale * i)
            If (Me.ImageScale < 0.005!) Then
                Me.ImageScale = 0.005!
            End If
            Me.cadPictBox.Invalidate()
        End If
    End Sub


    ' Properties
    Friend Property ApplicationLanguage() As MultipleLanguage
        Get
            Return Me.mlng
        End Get
        Set(ByVal value As MultipleLanguage)
            Me.mlng = value
        End Set
    End Property

    ''' <summary>
    ''' An X coordinate of the last mouse click position on the screen.
    ''' </summary>
    Public ReadOnly Property CurrentXClickPosition() As Integer
        Get
            Return Me.cX
        End Get
    End Property

    ''' <summary>
    ''' A Y coordinate of the last mouse click position on the screen.
    ''' </summary>
    Public ReadOnly Property CurrentYClickPosition() As Integer
        Get
            Return Me.cY
        End Get
    End Property

    ''' <summary>
    ''' A CAD image displayed in the main application form.
    ''' </summary>
    Friend Property Image() As CADImage
        Get
            Return Me.cadImageFld
        End Get
        Set(ByVal value As CADImage)
            Me.cadImageFld = value
        End Set
    End Property

    Friend ReadOnly Property ImageDRect() As DRect
        Get
            Return New DRect(CDbl(Me.LeftImagePosition), CDbl(Me.TopImagePosition), CDbl((Me.VisibleAreaSize.Width * Me.ImageScale)), CDbl((Me.VisibleAreaSize.Height * Me.ImageScale)))
        End Get
    End Property

    ''' <summary>
    ''' A previous value of the scale in which the current CAD image is displayed in the viewer.
    ''' </summary>
    Public Property ImagePreviousScale() As Single
        Get
            Return Me.prev_sc
        End Get
        Set(ByVal value As Single)
            Me.prev_sc = value
        End Set
    End Property

    Public ReadOnly Property ImageRectangleF() As RectangleF
        Get
            Return New RectangleF(Me.LeftImagePosition, Me.TopImagePosition, (Me.VisibleAreaSize.Width * Me.ImageScale), (Me.VisibleAreaSize.Height * Me.ImageScale))
        End Get
    End Property

    ''' <summary>
    ''' A scale in which the current CAD image is displayed in the viewer.
    ''' </summary>
    Public Property ImageScale() As Single
        Get
            Return Me.sc
        End Get
        Set(ByVal value As Single)
            Me.sc = value
        End Set
    End Property

    Public Property LeftImagePosition() As Single
        Get
            Return Me.pos.X
        End Get
        Set(ByVal value As Single)
            Me.pos.X = value
        End Set
    End Property

    ''' <summary>
    ''' A position of the current CAD image in relation to the top-left corner of the viewer.
    ''' </summary>
    Public Property Position() As PointF
        Get
            Return Me.pos
        End Get
        Set(ByVal value As PointF)
            Me.pos = value
        End Set
    End Property

    ''' <summary>
    ''' A previous position of the current CAD image in relation to the top-left corner of the viewer.
    ''' </summary>
    Public Property PreviousPosition() As PointF
        Get
            Return Me.old_Pos
        End Get
        Set(ByVal value As PointF)
            Me.old_Pos = value
        End Set
    End Property

    Private ReadOnly Property RealScale() As String
        Get
            If (Not Me.cadImageFld Is Nothing) Then
                Return String.Format("{0,2:F}%", (((CDbl((Me.VisibleAreaSize.Width * Me.ImageScale)) / Me.cadImageFld.AbsWidth) * Me.cadImageFld.MMToPixelX) * 100))
            End If
            Return String.Format("{0}%", Me.ImageScale)
        End Get
    End Property

    Private ReadOnly Property RealScaleDouble() As Double
        Get
            If (Not Me.cadImageFld Is Nothing) Then
                Return ((CDbl((Me.VisibleAreaSize.Width * Me.ImageScale)) / Me.cadImageFld.AbsWidth) * Me.cadImageFld.MMToPixelX)
            End If
            Return Me.ImageScale
        End Get
    End Property

    Public Property TopImagePosition() As Single
        Get
            Return Me.pos.Y
        End Get
        Set(ByVal value As Single)
            Me.pos.Y = value
        End Set
    End Property

    Public Property VisibleAreaSize() As SizeF
        Get
            Return Me.visibleArea
        End Get
        Set(ByVal value As SizeF)
            Me.visibleArea = value
        End Set
    End Property
End Class

Friend MustInherit Class ApplicationConstants
    ' Methods
    Protected Sub New()
    End Sub


    ' Fields
    Public Shared ReadOnly appconst As String = "Application"
    Public Shared ReadOnly appnamestr As String = "CADImportNet Demo"
    Public Shared ReadOnly backcolorstr As String = "BackgroundColor"
    Public Shared ReadOnly blackstr As String = "BLACK"
    Public Shared ReadOnly blackstr2 As String = "Black"
    Public Shared ReadOnly bmpextstr As String = ".BMP"
    Public Shared ReadOnly colorstr As String = "Color"
    Public Shared ReadOnly defaultstr As String = "Default"
    Public Shared ReadOnly drawmodestr As String = "drawMode"
    Public Shared ReadOnly dxfextstr As String = ".DXF"
    Public Shared ReadOnly emfextstr As String = ".EMF"
    Public Shared ReadOnly floatingstr As String = "floating"
    Public Shared ReadOnly freezestr As String = "Freeze"
    Public Shared ReadOnly gifextstr As String = ".GIF"
    Public Shared ReadOnly headstr1 As String = "Head1"
    Public Shared ReadOnly headstr2 As String = "Head2"
    Public Shared ReadOnly headstr3 As String = "Head3"
    Public Shared ReadOnly headstr4 As String = "Head4"
    Public Shared ReadOnly hoststr As String = "Host"
    Public Shared ReadOnly installstr As String = "Install"
    Public Shared ReadOnly jpgextstr As String = ".JPG"
    Public Shared ReadOnly languageIDstr As String = "LanguageID"
    Public Shared ReadOnly languagepath As String = "LanguagePath"
    Public Shared ReadOnly languagestr As String = "Language"
    Public Shared ReadOnly lngextstr As String = ".lng"
    Public Shared ReadOnly loadfilestr As String = "Loading file..."
    Public Shared ReadOnly msgBoxDebugCaption As String = "Debug application message"
    Public Shared ReadOnly namestr As String = "Name"
    Public Shared ReadOnly notsupportedextstr As String = "Not supported in current version!"
    Public Shared ReadOnly notsupportedstr As String = "not supported"
    Public Shared ReadOnly pngextstr As String = ".PNG"
    Public Shared ReadOnly portstr As String = "Port"
    Public Shared ReadOnly registerstr As String = "register"
    Public Shared ReadOnly sepstr As String = " - "
    Public Shared ReadOnly sepstr2 As String = " : "
    Public Shared ReadOnly sepstr3 As String = ";"
    Public Shared ReadOnly showentitystr As String = "ShowEntity"
    Public Shared ReadOnly shxpathcnstr As String = "SHXPathCount"
    Public Shared ReadOnly tiffextstr As String = ".TIFF"
    Public Shared ReadOnly truestr As String = "TRUE"
    Public Shared ReadOnly typelcstr As String = "Type_license"
    Public Shared ReadOnly visiblestr As String = "Visible"
    Public Shared ReadOnly whitestr As String = "White"
    Public Shared ReadOnly wmfextstr As String = ".WMF"
End Class
